@@ -50,7 +50,8 @@ enum option_keys_enum
 
   /* Only with long version (start with a value 1000, the rest will be set
      automatically). */
-  UI_KEY_ENVSEED         = 1000,
+  UI_KEY_APPEND          = 1000,
+  UI_KEY_ENVSEED,
   UI_KEY_ARGUMENTS,
 };
 
@@ -62,6 +63,6 @@ size_t *
 ui_read_ndim_dsize(char *filename, char *hdu, size_t *ndim);
 
 void
-freeandreport(struct arithmeticparams *p, struct timeval *t1);
+ui_free_report(struct arithmeticparams *p, struct timeval *t1);
 
 #endif
