@@ -5,7 +5,7 @@ ConvertType is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -468,10 +468,10 @@ ui_show_fonts(struct converttparams *p)
 
 
 
-/* Read and check ONLY the options. When arguments are involved, do the
-   check in 'ui_check_options_and_arguments'. */
+/* Check ONLY the options. When arguments are involved, do the check
+   in 'ui_check_options_and_arguments'. */
 static void
-ui_read_check_only_options(struct converttparams *p)
+ui_check_only_options(struct converttparams *p)
 {
   gal_data_t *cond;
 
@@ -703,11 +703,8 @@ ui_make_channels_ll(struct converttparams *p)
   /* Initialize the counting of channels. */
   p->numch=0;
 
-  /* If any standard input is provided, we want to process that first. Note
-     that since other input arguments are also allowed (as other channels),
-     we'll need to process the standard input independently first, then go
-     onto the possible list of other files.*/
-  lines=gal_txt_stdin_read(p->cp.stdintimeout);
+  /* If no input files are specified, check the standard input. */
+  lines=p->inputnames?NULL:gal_txt_stdin_read(p->cp.stdintimeout);
   if(lines)
     {
       data=gal_txt_image_read(NULL, lines, p->cp.minmapsize,
@@ -953,14 +950,10 @@ ui_prepare_input_channels(struct converttparams *p)
     error(EXIT_FAILURE, 0, "the number of input color channels has to "
           "be 1 (for non image data, grayscale or only K channel in "
           "CMYK), 3 (for RGB) and 4 (for CMYK). You have given %zu "
-          "color channels. Note 1: some file formats (for example "
-          "JPEG in RGB mode) can contain more than one color channel, "
-          "if such a file is given all its channels are read, so "
-          "separate them first. Note 2: if your first input channel "
-          "was given through the standard input (piped from another "
-          "program) you can fix this error by giving a larger value "
-          "to the '--stdintimeout' option (currently %ld "
-          "micro-seconds)", p->numch, p->cp.stdintimeout);
+          "color channels. Note that some file formats (for example "
+          "JPEG in RGB mode) can contain more than one color channel. "
+          "If such a file is given all its channels are read, so "
+          "separate them first", p->numch);
 
 
   /* If there are multiple color channels, then ignore the monotocolor
@@ -1781,9 +1774,8 @@ ui_read_check_inputs_setup(int argc, char *argv[], struct converttparams *p)
   gal_options_read_config_set(&p->cp);
 
 
-  /* Read the options into the program's structure, and check them and
-     their relations prior to printing. */
-  ui_read_check_only_options(p);
+  /* Sanity check only on options. */
+  ui_check_only_options(p);
 
 
   /* Print the option values if asked. Note that this needs to be done
@@ -1792,6 +1784,10 @@ ui_read_check_inputs_setup(int argc, char *argv[], struct converttparams *p)
   gal_options_print_state(&p->cp);
 
 
+  /* Prepare all the options as FITS keywords to write in output later. */
+  gal_options_as_fits_keywords(&p->cp);
+
+
   /* Check that the options and arguments fit well with each other. Note
      that arguments don't go in a configuration file. So this test should
      be done after (possibly) printing the option values. */
