@@ -5,7 +5,7 @@ CosmicCalculator is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -61,7 +61,7 @@ enum option_keys_enum
   UI_KEY_AGENOW              = 'G',
   UI_KEY_CRITICALDENSITYNOW  = 'C',
   UI_KEY_PROPERDISTANCE      = 'd',
-  UI_KEY_ANGULARDIMDIST      = 'A',
+  UI_KEY_ANGULARDIAMDIST     = 'A',
   UI_KEY_ARCSECTANDIST       = 's',
   UI_KEY_LUMINOSITYDIST      = 'L',
   UI_KEY_DISTANCEMODULUS     = 'u',
