@@ -5,7 +5,7 @@ Crop is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -44,6 +44,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 
 
+
 /* Write the log entry for each crop.
 
    A maximum length of FILENAME_BUFFER_IN_VERB characters is set for the
@@ -211,7 +212,8 @@ crop_mode_img(void *inparam)
   /* The whole catalog is from one image, so you can get the
      information here:*/
   img=&p->imgs[crp->in_ind];
-  crp->infits=gal_fits_hdu_open_format(img->name, p->cp.hdu, 0);
+  crp->infits=gal_fits_hdu_open_format(img->name, p->cp.hdu, 0,
+                                       "--hdu");
 
   /* Go over all the outputs that are assigned to this thread: */
   for(i=0; crp->indexs[i]!=GAL_BLANK_SIZE_T; ++i)
@@ -235,8 +237,7 @@ crop_mode_img(void *inparam)
           /* Check if the center of the crop is filled or not. */
           crp->centerfilled=onecrop_center_filled(crp);
 
-          /* Add the final headers and close output FITS image: */
-          gal_fits_key_write_version_in_ptr(NULL, NULL, crp->outfits);
+          /* Close output FITS image. */
           status=0;
           if( fits_close_file(crp->outfits, &status) )
             gal_fits_io_error(status, "CFITSIO could not close "
@@ -254,7 +255,8 @@ crop_mode_img(void *inparam)
         }
       else crp->centerfilled=0;
 
-      /* Report the status on stdout if verbose mode is requested. */
+      /* Status update (for return value and standard output or log).*/
+      p->outmade[crp->out_ind] = crp->outfits || crp->outinstdout;
       if(!p->cp.quiet) crop_verbose_info(crp);
       if(p->cp.log)    crop_write_to_log(crp);
     }
@@ -307,7 +309,7 @@ crop_mode_wcs(void *inparam)
           {
             /* Open the input FITS file. */
             crp->infits=gal_fits_hdu_open_format(p->imgs[crp->in_ind].name,
-                                                 p->cp.hdu, 0);
+                                                 p->cp.hdu, 0, "--hdu");
 
             /* If a name isn't set yet, set it. */
             if(crp->name==NULL) onecrop_name(crp);
@@ -340,8 +342,7 @@ crop_mode_wcs(void *inparam)
           /* See if the center is filled. */
           crp->centerfilled=onecrop_center_filled(crp);
 
-          /* Write all the dependency versions and close the file. */
-          gal_fits_key_write_version_in_ptr(NULL, NULL, crp->outfits);
+          /* Close the file. */
           status=0;
           if( fits_close_file(crp->outfits, &status) )
             gal_fits_io_error(status, "CFITSIO could not close the "
@@ -361,8 +362,8 @@ crop_mode_wcs(void *inparam)
         }
 
 
-
-      /* Report the status on stdout if verbose mode is requested. */
+      /* Status update (for return value and standard output or log).*/
+      p->outmade[crp->out_ind] = crp->outfits || crp->outinstdout;
       if(!p->cp.quiet) crop_verbose_info(crp);
       if(p->cp.log)    crop_write_to_log(crp);
     }
@@ -393,19 +394,19 @@ crop_mode_wcs(void *inparam)
 
 
 /*******************************************************************/
-/**************           Output function           ****************/
+/**************         Top-level function          ****************/
 /*******************************************************************/
 /* Main function for the Image Mode. It is assumed that if only one
    crop box from each input image is desired, the first and last
    pixels are already set, irrespective of how the user specified that
-   box.  */
-void
+   box. */
+int
 crop(struct cropparams *p)
 {
-  int err=0;
   char *tmp;
   pthread_t t; /* We don't use the thread id, so all are saved here. */
   char *mmapname;
+  int err=0, out;
   pthread_attr_t attr;
   pthread_barrier_t b;
   struct onecropparams *crp;
@@ -416,16 +417,20 @@ crop(struct cropparams *p)
 
 
   /* Set the function to run: */
-  modefunction = p->mode==IMGCROP_MODE_IMG ? &crop_mode_img : &crop_mode_wcs;
+  modefunction = ( p->mode==IMGCROP_MODE_IMG
+                   ? &crop_mode_img : &crop_mode_wcs );
 
 
-  /* Allocate the array of structures to keep the thread and parameters for
-     each thread. */
+  /* Necessary allocations: the array of structures to keep the thread and
+     parameters for each thread and an array to keep track of the built
+     outputs. */
   errno=0;
   crp=malloc(nt*sizeof *crp);
   if(crp==NULL)
     error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for 'crp'",
           __func__, nt*sizeof *crp);
+  p->outmade=gal_pointer_allocate(GAL_TYPE_UINT8, p->numin, 1, __func__,
+                                  "p->outmade");
 
 
   /* Distribute the indexs into the threads (for clarity, this is needed
@@ -489,9 +494,20 @@ crop(struct cropparams *p)
       gal_list_str_free(comments, 1);
     }
 
+
+  /* Prepare the return value: if any outputs were made, return
+     EXIT_SUCCESS, otherwise, return EXIT_FAILURE. */
+  out=EXIT_FAILURE;
+  for(i=0;i<p->numin;++i) if(p->outmade[i]) { out=EXIT_SUCCESS; break; }
+
+
   /* Print the final verbose info, save log, and clean up: */
   if(mmapname) gal_pointer_mmap_free(&mmapname, p->cp.quietmmap);
   else         free(indexs);
   crop_verbose_final(p);
+  free(p->outmade);
   free(crp);
+
+  /* Return with the progarm's return value. */
+  return out;
 }
