@@ -5,7 +5,7 @@ Crop is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2020, Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -45,8 +45,8 @@ enum program_args_groups
 
 /* Available letters for short options:
 
-   a d e f g i j k m r t u v y
-   A B E G H J L Q R W X Y
+   d e f g i j k m r u v y
+   B E G H J L Q R W Y
 */
 enum option_keys_enum
 {
@@ -60,8 +60,12 @@ enum option_keys_enum
   UI_KEY_ZEROISNOTBLANK = 'z',
   UI_KEY_MODE           = 'O',
   UI_KEY_WIDTH          = 'w',
+  UI_KEY_WIDTHINPIX     = 'X',
   UI_KEY_CENTER         = 'c',
   UI_KEY_COORDCOL       = 'x',
+  UI_KEY_ONEELEMSTDOUT  = 't',
+  UI_KEY_METANAME       = 'a',
+  UI_KEY_APPEND         = 'A',
 
   /* Only with long version (start with a value 1000, the rest will be set
      automatically). */
@@ -71,6 +75,7 @@ enum option_keys_enum
   UI_KEY_POLYGONOUT,
   UI_KEY_POLYGONSORT,
   UI_KEY_CHECKCENTER,
+  UI_KEY_PRIMARYIMGHDU,
 };
 
 
