@@ -6,7 +6,7 @@ Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
      Pedram Ashofteh-Ardakani <pedramardakani@pm.me>
-Copyright (C) 2017-2023 Free Software Foundation, Inc.
+Copyright (C) 2017-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -178,7 +178,7 @@ fits_print_extension_info(struct fitsparams *p)
         }
 
 
-      /* Read the extension name*/
+      /* Read the extension name. */
       fits_read_keyword(fptr, "EXTNAME", extname, NULL, &status);
       switch(status)
         {
@@ -206,7 +206,7 @@ fits_print_extension_info(struct fitsparams *p)
         case 0:
           /* For tables, we don't bother reading 'BUNIT', because it is
              meaningless even if it exists (each colum has its separate
-             units). So 'status' will be zero in this case.*/
+             units). So 'status' will be zero in this case. */
           if(hdutype==IMAGE_HDU)
             gal_fits_key_clean_str_value(bunit);
           else /* Its a table HDU. */
@@ -308,11 +308,12 @@ fits_print_extension_info(struct fitsparams *p)
         printf("           ('%s': no unit in HDU metadata, or "
                "HDU is a table)\n", GAL_BLANK_STRING);
       if(hascomments)
-        printf(" Column 6: Comments about the HDU (e.g., if its HEALpix, or "
-               "etc).\n");
+        printf(" Column 6: Comments about the HDU (e.g., if its HEALpix, "
+               "or etc).\n");
       printf("-----\n");
     }
-  gal_table_write(cols, NULL, NULL, GAL_TABLE_FORMAT_TXT, NULL, NULL, 0);
+  gal_table_write(cols, NULL, NULL, GAL_TABLE_FORMAT_TXT, NULL, NULL,
+                  0, 0);
   gal_list_data_free(cols);
 }
 
@@ -347,7 +348,20 @@ fits_hdu_number(struct fitsparams *p)
 static void
 fits_datasum(struct fitsparams *p)
 {
-  printf("%ld\n", gal_fits_hdu_datasum(p->input->v, p->cp.hdu, "--hdu"));
+  char *out;
+
+  if(p->datasum)
+    printf("%ld\n", gal_fits_hdu_datasum(p->input->v, p->cp.hdu, "--hdu"));
+  else if(p->datasumencoded)
+    {
+      out=gal_fits_hdu_datasum_encoded(p->input->v, p->cp.hdu, "--hdu");
+      printf("%s\n", out);
+      free(out);
+    }
+  else
+    error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at '%s' to fix "
+          "this bug! Both 'datasum' and 'datasumencoded' are zero",
+          __func__, PACKAGE_BUGREPORT);
 }
 
 
@@ -393,7 +407,7 @@ fits_pixelscale(struct fitsparams *p)
 
   /* If not in quiet-mode, print some extra information. We don't want the
      last number to have a space after it, so we'll write the last one
-     outside the loop.*/
+     outside the loop. */
   if(p->cp.quiet==0)
     {
       printf("Basic information for --pixelscale (remove extra info "
@@ -513,7 +527,7 @@ fits_pixelarea(struct fitsparams *p)
   /* Calculate the pixel-scale in each dimension. */
   pixelscale=gal_wcs_pixel_scale(wcs);
 
-  /* Calcluate the pixel area (currently only in arcsec^N) */
+  /* Calcluate the pixel area (currently only in arcsec^N). */
   area=1;
   for(i=0;i<ndim;++i) area *= pixelscale[i]*3600;
   printf("%g\n", area);
@@ -559,13 +573,13 @@ fits_skycoverage(struct fitsparams *p)
       switch(ndim)
         {
         case 2:
-          printf("  Center: %-15.10g%-15.10g\n", center[0], center[1]);
-          printf("  Width:  %-15.10g%-15.10g\n", width[0],  width[1]);
+          printf("  Center: %-15.10g %-15.10g\n", center[0], center[1]);
+          printf("  Width:  %-15.10g %-15.10g\n", width[0],  width[1]);
           break;
         case 3:
-          printf("  Center: %-15.10g%-15.10g%-15.10g\n", center[0],
+          printf("  Center: %-15.10g %-15.10g %-15.10g\n", center[0],
                  center[1], center[2]);
-          printf("  width:  %-15.10g%-15.10g%-15.10g\n", width[0],
+          printf("  width:  %-15.10g %-15.10g %-15.10g\n", width[0],
                  width[1], width[2]);
           break;
         default:
@@ -579,7 +593,7 @@ fits_skycoverage(struct fitsparams *p)
                        0, 0, &nwcs, "--hdu");
       printf("\nSky coverage by range along dimensions:\n");
       for(i=0;i<ndim;++i)
-        printf("  %-8s %-15.10g%-15.10g\n", gal_wcs_dimension_name(wcs, i),
+        printf("  %-8s %-15.10g %-15.10g\n", gal_wcs_dimension_name(wcs, i),
                min[i], max[i]);
       wcsfree(wcs);
     }
@@ -634,7 +648,7 @@ fits_certain_hdu(struct fitsparams *p, int list1has0,
   int has=0, naxis, hducounter=1, hdutype, status=0;
 
   /* Make sure the given file exists: CFITSIO adds '.gz' silently (see more
-     in the comments within 'gal_fits_hdu_open')*/
+     in the comments within 'gal_fits_hdu_open'). */
   gal_checkset_check_file(p->input->v);
 
   /* Open the FITS file. */
@@ -726,7 +740,7 @@ fits_list_all_hdus(struct fitsparams *p)
   int hducounter=1, hdutype, status=0;
 
   /* Make sure the given file exists: CFITSIO adds '.gz' silently (see more
-     in the comments within 'gal_fits_hdu_open')*/
+     in the comments within 'gal_fits_hdu_open'). */
   gal_checkset_check_file(p->input->v);
 
   /* Open the FITS file. */
@@ -788,7 +802,7 @@ fits_hdu_remove(struct fitsparams *p, int *r)
 
 
 /* This is similar to the library's 'gal_fits_open_to_write', except that
-   it won't create an empty first extension.*/
+   it won't create an empty first extension. */
 fitsfile *
 fits_open_to_write_no_blank(char *filename)
 {
@@ -837,7 +851,7 @@ fits_hdu_copy(struct fitsparams *p, int cut1_copy0, int *r)
       in=gal_fits_hdu_open(p->input->v, hdu,
                            cut1_copy0 ? READWRITE : READONLY, 1, hopt);
 
-      /* If the output isn't opened yet, open it.  */
+      /* If the output isn't opened yet, open it. */
       if(out==NULL)
         out = ( ( gal_fits_hdu_format(p->input->v, hdu, hopt)==IMAGE_HDU
                   && p->primaryimghdu )
@@ -870,6 +884,9 @@ fits_hdu_copy(struct fitsparams *p, int cut1_copy0, int *r)
 
 
 
+/***************************************************************/
+/*************         Top-level function          *************/
+/***************************************************************/
 int
 fits(struct fitsparams *p)
 {
@@ -889,7 +906,6 @@ fits(struct fitsparams *p)
 
       /* Options that must be called alone. */
       if(p->numhdus)               fits_hdu_number(p);
-      else if(p->datasum)          fits_datasum(p);
       else if(p->pixelscale)       fits_pixelscale(p);
       else if(p->pixelareaarcsec2) fits_pixelarea(p);
       else if(p->skycoverage)      fits_skycoverage(p);
@@ -898,6 +914,7 @@ fits(struct fitsparams *p)
       else if(p->listimagehdus)    fits_certain_hdu(p, 1, 0);
       else if(p->listtablehdus)    fits_certain_hdu(p, 1, 1);
       else if(p->listallhdus)      fits_list_all_hdus(p);
+      else if(p->datasum || p->datasumencoded) fits_datasum(p);
 
       /* Options that can be called together. */
       else
