@@ -6,7 +6,7 @@ Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
      Pedram Ashofteh-Ardakani <pedramardakani@pm.me>
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -29,9 +29,11 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <stdio.h>
 #include <string.h>
 
+#include <gnuastro/txt.h>
 #include <gnuastro/wcs.h>
 #include <gnuastro/fits.h>
 
+
 #include <gnuastro-internal/options.h>
 #include <gnuastro-internal/checkset.h>
 #include <gnuastro-internal/fixedstringmacros.h>
@@ -155,7 +157,7 @@ parse_opt(int key, char *arg, struct argp_state *state)
 {
   struct fitsparams *p = state->input;
 
-  /* Pass 'gal_options_common_params' into the child parser.  */
+  /* Pass 'gal_options_common_params' into the child parser. */
   state->child_inputs[0] = &p->cp;
 
   /* In case the user incorrectly uses the equal sign (for example
@@ -276,10 +278,11 @@ ui_check_copykeys(struct fitsparams *p)
              of the 'switch'). Recall that according to the FITS standard,
              a keyword name can only contain digits, alphabetic characters,
              '-', or '_'. See "Section 4.1.2.1. Keyword name" of the FITS
-             4.0 standard.*/
+             4.0 standard. */
           if( isalpha(*pt) || *pt=='-' || *pt=='_' ) break;
 
-          /* Print an error if control reaches here because  */
+          /* Print an error and abort if control reaches here (as described
+             in the error message). */
           error(EXIT_FAILURE, 0, "value to '--copykeys' must either be a "
                 "range of numbers (for example '--copykeys=10:20') or a "
                 "set of names (for example '--copykeys=KEY1,KEY2', for "
@@ -462,16 +465,16 @@ ui_read_check_mode_keyword(struct fitsparams *p)
 
 
 
-/* Same for the extension-related options */
+/* Same for the extension-related options. */
 static void
 ui_read_check_mode_extension(struct fitsparams *p)
 {
   uint8_t stdoutcheck=0;
 
   if( p->remove || p->copy || p->cut || p->numhdus || p->datasum
-      || p->pixelscale || p->pixelareaarcsec2 || p->skycoverage
-      || p->hastablehdu || p->hasimagehdu || p->listtablehdus
-      || p->listimagehdus )
+      || p->datasumencoded || p->pixelscale || p->pixelareaarcsec2
+      || p->skycoverage || p->hastablehdu || p->hasimagehdu
+      || p->listtablehdus || p->listimagehdus )
     {
       /* A small sanity check. */
       if(p->mode!=FITS_MODE_INVALID)
@@ -479,10 +482,10 @@ ui_read_check_mode_extension(struct fitsparams *p)
               "cannot be called together");
 
       /* Some HDU options cannot be called with other options. */
-      stdoutcheck = ( p->numhdus + p->datasum + p->pixelscale
-                      + p->pixelareaarcsec2 + p->skycoverage
-                      + p->hastablehdu + p->hasimagehdu + p->listtablehdus
-                      + p->listimagehdus );
+      stdoutcheck = ( p->numhdus + p->datasum + p->datasumencoded
+                      + p->pixelscale + p->pixelareaarcsec2
+                      + p->skycoverage + p->hastablehdu + p->hasimagehdu
+                      + p->listtablehdus + p->listimagehdus );
 
       /* Make sure if an output file is needed. */
       if(stdoutcheck)
@@ -530,10 +533,10 @@ ui_read_check_mode_extension(struct fitsparams *p)
 
 
 
-/* Read and check ONLY the options. When arguments are involved, do the
-   check in 'ui_check_options_and_arguments'. */
+/* Check ONLY the options. When arguments are involved, do the check
+   in 'ui_check_options_and_arguments'. */
 static void
-ui_read_check_only_options(struct fitsparams *p)
+ui_check_only_options(struct fitsparams *p)
 {
   /* Check the given optinos and set the operating mode accordingly. */
   ui_read_check_mode_keyword(p);
@@ -561,17 +564,35 @@ ui_read_check_only_options(struct fitsparams *p)
 static void
 ui_check_options_and_arguments(struct fitsparams *p)
 {
-  /* Make sure an input file name was given and if it was a FITS file, that
-     a HDU is also given. */
-  if(p->input==NULL)
-    error(EXIT_FAILURE, 0, "no input file is specified");
-  gal_list_str_reverse(&p->input);
 
-  /* More than one input is currently only acceptable with the '--keyvalue'
-     option. */
-  if( gal_list_str_number(p->input) > 1 && p->keyvalue==NULL)
-    error(EXIT_FAILURE, 0, "one input file is expected but %zu input "
-          "files are given", gal_list_str_number(p->input));
+
+  /* Other than the '--keyvalue' option, the rest of the operations only
+     require a single file. */
+  if(p->keyvalue)
+    {
+      /* If '--arguments' is given and there is no input files, read the
+         names of the inputs from that. Otherwise, complain about not
+         having any input. */
+      if(p->input==NULL)
+        {
+          if(p->arguments)
+            p->input=gal_txt_read_to_list(p->arguments);
+          else
+            error(EXIT_FAILURE, 0, "no input file(s) specified");
+        }
+    }
+  else
+    {
+      /* If there are any inputs. */
+      if(p->input==NULL)
+        error(EXIT_FAILURE, 0, "no input file is specified");
+      gal_list_str_reverse(&p->input);
+
+      /* Only one input. */
+      if( gal_list_str_number(p->input) > 1)
+        error(EXIT_FAILURE, 0, "one input file is expected but %zu input "
+              "files are given", gal_list_str_number(p->input));
+    }
 }
 
 
@@ -667,12 +688,13 @@ ui_fill_fits_headerll(gal_list_str_t *input, gal_fits_list_key_t **output,
         }
       while(++c<cf);
 
-      /* See if this is an option that needs a value or not.*/
+      /* See if this is an option that needs a value or not. */
       needsvalue=1;
       if(keyname)
         {
           if( !strcasecmp(keyname,"checksum")
-              || !strcasecmp(keyname,"datasum") )
+              || !strcasecmp(keyname,"datasum")
+              || !strcasecmp(keyname,"datasum-encoded"))
             needsvalue=0;
         }
 
@@ -796,7 +818,7 @@ ui_read_check_inputs_setup(int argc, char *argv[], struct fitsparams *p)
 #include "args.h"
 
 
-  /* Initialize the options and necessary information.  */
+  /* Initialize the options and necessary information. */
   ui_initialize_options(p, program_options, gal_commonopts_options);
 
 
@@ -819,9 +841,8 @@ ui_read_check_inputs_setup(int argc, char *argv[], struct fitsparams *p)
   gal_options_read_config_set(&p->cp);
 
 
-  /* Read the options into the program's structure, and check them and
-     their relations prior to printing. */
-  ui_read_check_only_options(p);
+  /* Sanity check only on options. */
+  ui_check_only_options(p);
 
 
   /* Print the option values if asked. Note that this needs to be done
@@ -863,7 +884,7 @@ ui_read_check_inputs_setup(int argc, char *argv[], struct fitsparams *p)
 /************      Free allocated, report         *************/
 /**************************************************************/
 void
-ui_free_and_report(struct fitsparams *p)
+ui_free_report(struct fitsparams *p)
 {
   /* Free the allocated arrays: */
   free(p->cp.output);
