@@ -104,6 +104,6 @@ ui_read_check_inputs_setup(int argc, char *argv[],
                            struct fitsparams *p);
 
 void
-ui_free_and_report(struct fitsparams *p);
+ui_free_report(struct fitsparams *p);
 
 #endif
