@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -151,7 +151,7 @@ saveindividual(struct mkonthread *mkp)
   /* Write the array to the file (a separately built PSF doesn't need WCS
      coordinates). */
   if(ibq->ispsf && p->psfinimg==0)
-    gal_fits_img_write(ibq->image, filename, NULL, PROGRAM_NAME);
+    gal_fits_img_write(ibq->image, filename, NULL, 0);
   else
     {
       /* Allocate space for the corrected crpix and fill it in. Both
@@ -159,17 +159,20 @@ saveindividual(struct mkonthread *mkp)
       crpix=gal_pointer_allocate(GAL_TYPE_FLOAT64, ndim, 0, __func__,
                                  "crpix");
       for(i=0;i<ndim;++i)
-        crpix[i] = ((double *)(p->crpix->array))[i] - os*(mkp->fpixel_i[i]-1);
+        crpix[i] = ( ((double *)(p->crpix->array))[i]
+                     - os*(mkp->fpixel_i[i]-1) );
 
       /* Write the image. */
       gal_fits_img_write_corr_wcs_str(ibq->image, filename, p->wcsstr,
-                                      p->wcsnkeyrec, crpix, NULL,
-                                      PROGRAM_NAME);
+                                      p->wcsnkeyrec, crpix, NULL, 0);
     }
   ibq->indivcreated=1;
 
 
-  /* Write profile settings into the FITS file. */
+  /* Write profile settings into a keyword list. */
+  gal_fits_key_list_title_add(&keys, "Profile configuration", 0);
+  gal_fits_key_list_add(&keys, GAL_TYPE_STRING, "EXTNAME", 0,
+                        "PROFILE-CONFIG", 0, "HDU name", 0, NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_STRING, "PROFILE", 0,
                         ui_profile_name_write(mkp->func), 0,
                         "Radial function", 0, NULL, 0);
@@ -188,28 +191,28 @@ saveindividual(struct mkonthread *mkp)
                         0, NULL, 0);
   if( mkp->func==PROFILE_SERSIC || mkp->func==PROFILE_MOFFAT )
     gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "PINDEX", 0,
-                          &p->r[id], 0, "Index (Sersic or Moffat) of profile"
-                          "in catalog", 0, NULL, 0);
+                          &p->r[id], 0, "Index (Sersic or Moffat) of "
+                          "profile in catalog", 0, NULL, 0);
   if(ndim==2)
     {
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "PA_DEG", 0,
                             &p->p1[id], 0, "Position angle of profile in "
                             "catalog", 0, "deg", 0);
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "AXISRATIO", 0,
-                            &p->q1[id], 0, "Axis ratio of profile in catalog",
-                            0, NULL, 0);
+                            &p->q1[id], 0, "Axis ratio of profile in "
+                            "catalog", 0, NULL, 0);
     }
   else
     {
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "PA1_DEG", 0,
-                            &p->p1[id], 0, "First X-Z-X Euler angle in 3D", 0,
-                            "deg", 0);
+                            &p->p1[id], 0, "First X-Z-X Euler angle in "
+                            "3D", 0, "deg", 0);
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "PA2_DEG", 0,
-                            &p->p2[id], 0, "Second X-Z-X Euler angle in 3D", 0,
-                            "deg", 0);
+                            &p->p2[id], 0, "Second X-Z-X Euler angle in "
+                            "3D", 0, "deg", 0);
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "PA3_DEG", 0,
-                            &p->p3[id], 0, "Third X-Z-X Euler angle in 3D", 0,
-                            "deg", 0);
+                            &p->p3[id], 0, "Third X-Z-X Euler angle in "
+                            "3D", 0, "deg", 0);
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "AXISRATIO1", 0,
                             &p->q1[id], 0, "Axis ratio along second dim",
                             0, NULL, 0);
@@ -227,8 +230,8 @@ saveindividual(struct mkonthread *mkp)
                         (void *)(p->rng_name), 0,
                         "Name of random number generator", 0, NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_ULONG, "RNGSEED", 0,
-                        &mkp->rng_seed, 0, "Seed of random number generator",
-                        0, NULL, 0);
+                        &mkp->rng_seed, 0, "Seed of random number "
+                        "generator", 0, NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_SIZE_T, "NUMRANDOM", 0,
                         &p->numrandom, 0,
                         "Number of random points in central pixels", 0,
@@ -244,8 +247,8 @@ saveindividual(struct mkonthread *mkp)
                         &p->oversample, 0, "Oversampling factor", 0,
                         NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_UINT8, "TUNITINP", 0,
-                        &p->tunitinp, 0, "Truncation is in units of pixels, "
-                        "not radius", 0, NULL, 0);
+                        &p->tunitinp, 0, "Truncation is in units of "
+                        "pixels, not radius", 0, NULL, 0);
   if( !isnan(p->zeropoint) )
       gal_fits_key_list_add(&keys, GAL_TYPE_FLOAT32, "ZEROPOINT", 0,
                             &p->zeropoint, 0, "Zeropoint magnitude", 0,
@@ -265,9 +268,10 @@ saveindividual(struct mkonthread *mkp)
                         &p->magatpeak, 0, "Magnitude is for peak pixel, "
                         "not full profile", 0, NULL, 0);
 
+
+  /* Write the keyword list into the output file. */
   gal_fits_key_list_reverse(&keys);
-  gal_fits_key_write_config(&keys, "Profile configuration",
-                            "PROFILE-CONFIG", filename, "0", "NONE");
+  gal_fits_key_write(keys, filename, "0", "NONE", 1, 0);
 
 
   /* Report if in verbose mode. */
@@ -363,7 +367,6 @@ mkprof_build_single(struct mkonthread *mkp, long *fpixel_i, long *lpixel_i,
           if(dsize[i] != ibq->image->dsize[i]) needs_crop=1;
         }
 
-
       /* Define the individual overlap tile. */
       if(needs_crop)
         {
@@ -378,7 +381,6 @@ mkprof_build_single(struct mkonthread *mkp, long *fpixel_i, long *lpixel_i,
                                     NULL, 0, -1, 1, NULL, NULL, NULL);
       ibq->overlap_i->block=ibq->image;
 
-
       /* Define the merged overlap tile. */
       ind=gal_dimension_coord_to_index(ndim, p->out->dsize, start_mrg);
       ptr=gal_pointer_increment(p->out->array, ind, p->out->type);
@@ -614,10 +616,21 @@ mkprof_write(struct mkprofparams *p)
   double sum;
   char *jobname;
   struct timeval t1;
+  float *o, *of, oinit=NAN;
   gal_data_t *out=p->out, *log;
   struct builtqueue *ibq=NULL, *tbq;
   size_t complete=0, num=p->num, clog;
 
+  /* If we want to replace the pixel values, initialize the output array
+     with an impossible value (smallest possible 32-bit floating point
+     number). This is because we are always replacing the pixels with the
+     maximum to ensure reproducibility in multi-threaded operations. */
+  if(p->replace)
+    {
+      gal_type_min(GAL_TYPE_FLOAT32, &oinit);
+      of=(o=out->array)+out->size; do *o++=oinit; while(o<of);
+    }
+
   /* Write each image into the output array. */
   while(complete<p->num)
     {
@@ -645,7 +658,11 @@ mkprof_write(struct mkprofparams *p)
          array. */
       if(ibq->overlaps && out)
         GAL_TILE_PO_OISET(float,float,ibq->overlap_i,ibq->overlap_m,1,0, {
-            *o  = p->replace ? ( *i>*o ? *i : *o ) :  (*i + *o);
+            /* The '*i>*o' condition is there to have a reproducible output
+               in multi-threaded scenarios (where the order can differ). */
+            *o  = ( p->replace
+                    ? ( *o==oinit ? *i : ( *i>*o ? *i : *o ) )
+                    :  (*i + *o) );
             sum += *i;
           });
 
@@ -701,6 +718,15 @@ mkprof_write(struct mkprofparams *p)
     }
 
 
+  /* In case we had initialized the output pixels, set all the ones that
+     were not filled back to zero. */
+  if(p->replace)
+    {
+      of=(o=out->array)+out->size;
+      do *o = *o==oinit ? 0.0 : *o; while(++o<of);
+    }
+
+
   /* Write the final array to the output FITS image if a merged image is to
      be created. */
   if(out)
@@ -708,24 +734,22 @@ mkprof_write(struct mkprofparams *p)
       /* Get the current time for verbose output. */
       if(!p->cp.quiet) gettimeofday(&t1, NULL);
 
+      /* Write the configuration keywords. */
+      gal_fits_key_write_filename("input", p->catname, &p->cp.ckeys, 1,
+                                  p->cp.quiet);
+      gal_fits_key_write(p->cp.ckeys, p->mergedimgname, "0", "NONE", 1, 1);
+
       /* Write the final image into a FITS file with the requested
          type. Until now, we were using 'p->wcs' for the WCS, but from now
          on, will put it in 'out' to also free it while freeing 'out'. */
       out->wcs=p->wcs;
       gal_fits_img_write_to_type(out, p->mergedimgname, NULL,
-                                 PROGRAM_NAME, p->cp.type);
+                                 p->cp.type, 0);
       p->wcs=NULL;
 
       /* Clean up */
       gal_data_free(out);
 
-      /* Write the configuration keywords. */
-      gal_fits_key_write_filename("input", p->catname, &p->cp.okeys, 1,
-                                  p->cp.quiet);
-      gal_fits_key_write_config(&p->cp.okeys, "MakeProfiles configuration",
-                                "MKPROF-CONFIG", p->mergedimgname, "0",
-                                "NONE");
-
       /* In verbose mode, print the information. */
       if(!p->cp.quiet)
         {
@@ -757,7 +781,7 @@ mkprof_write(struct mkprofparams *p)
 
 
 /**************************************************************/
-/************           Outside function          *************/
+/************         Top-level function          *************/
 /**************************************************************/
 void
 mkprof(struct mkprofparams *p)
