@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2021, Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -31,7 +31,7 @@ struct mkonthread
 {
   /* General parameters: */
   double                r;   /* Elliptical radius at this point.      */
-  double         coord[3];   /* Pixel coordinate.                     */
+  double         coord[3];   /* Pixel coord. (from profile center).   */
   double         lower[3];   /* Coordinates of lower pixel position.  */
   double        higher[3];   /* Coordinates of higher pixel position. */
   double             c[3];   /* Cosine of position angle(s).          */
@@ -49,6 +49,7 @@ struct mkonthread
   long        fpixel_i[3];   /* fpixel_i before running overlap.      */
   int          correction;   /* ==1: correct the pixels afterwards.   */
   unsigned long  rng_seed;   /* Seed used to generate this profile.   */
+  gal_data_t   *customimg;   /* Custom image for this profile.        */
 
   /* Random number generator: */
   gsl_rng            *rng;   /* Copy of main random number generator. */
