@@ -5,7 +5,7 @@ NoiseChisel is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2022 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -226,7 +226,7 @@ threshold_write_sn_table(struct noisechiselparams *p, gal_data_t *insn,
      FITS file. We have already deleted any existing file with the same
      name in 'ui_set_output_names'.*/
   gal_table_write(cols, NULL, comments, p->cp.tableformat, filename,
-                  extname, 0);
+                  extname, 0, 0);
 
 
   /* Clean up (if necessary). */
@@ -300,12 +300,12 @@ threshold_interp_smooth(struct noisechiselparams *p, gal_data_t **first,
       (*second)->name="THRESH2_INTERP";
       if(third) (*third)->name="THRESH3_INTERP";
       gal_tile_full_values_write(*first, tl, !p->ignoreblankintiles,
-                                 filename, NULL, PROGRAM_NAME);
+                                 filename, NULL, 0);
       gal_tile_full_values_write(*second, tl, !p->ignoreblankintiles,
-                                 filename, NULL, PROGRAM_NAME);
+                                 filename, NULL, 0);
       if(third)
         gal_tile_full_values_write(*third, tl, !p->ignoreblankintiles,
-                                   filename, NULL, PROGRAM_NAME);
+                                   filename, NULL, 0);
       (*first)->name = (*second)->name = NULL;
       if(third) (*third)->name=NULL;
     }
@@ -341,12 +341,12 @@ threshold_interp_smooth(struct noisechiselparams *p, gal_data_t **first,
           (*second)->name="THRESH2_SMOOTH";
           if(third) (*third)->name="THRESH3_SMOOTH";
           gal_tile_full_values_write(*first, tl, !p->ignoreblankintiles,
-                                     filename, NULL, PROGRAM_NAME);
+                                     filename, NULL, 0);
           gal_tile_full_values_write(*second, tl, !p->ignoreblankintiles,
-                                     filename, NULL, PROGRAM_NAME);
+                                     filename, NULL, 0);
           if(third)
             gal_tile_full_values_write(*third, tl, !p->ignoreblankintiles,
-                                       filename, NULL, PROGRAM_NAME);
+                                       filename, NULL, 0);
           (*first)->name = (*second)->name = NULL;
           if(third) (*third)->name=NULL;
         }
@@ -533,6 +533,8 @@ threshold_good_error(size_t number, int before0_after1, size_t interpnumngb)
                   "(where the number may decrease even further).");
   char *in3 = ( before0_after1
                 ? "\n"
+                  "  - (slightly) Decrease '--outliernumngb' to use less "
+                  "tiles to find outliers.\n"
                   "  - (slightly) Increase '--outliersclip' to reject less "
                   "as outliers.\n"
                   "  - (slightly) Increase '--outliersigma' to reject less "
@@ -599,11 +601,11 @@ threshold_quantile_find_apply(struct noisechiselparams *p)
      the full input when 'oneelempertile' isn't requested. */
   if(p->qthreshname && !tl->oneelempertile)
     {
-      gal_fits_img_write(p->conv ? p->conv : p->input, p->qthreshname, NULL,
-                         PROGRAM_NAME);
+      gal_fits_img_write(p->conv ? p->conv : p->input, p->qthreshname,
+                         NULL, 0);
       if(p->wconv)
         gal_fits_img_write(p->wconv ? p->wconv : p->input, p->qthreshname,
-                           NULL, PROGRAM_NAME);
+                           NULL, 0);
     }
 
 
@@ -652,10 +654,10 @@ threshold_quantile_find_apply(struct noisechiselparams *p)
       qprm.noerode_th->name="QTHRESH_NOERODE";
       gal_tile_full_values_write(qprm.erode_th, tl,
                                  !p->ignoreblankintiles,
-                                 p->qthreshname, NULL, PROGRAM_NAME);
+                                 p->qthreshname, NULL, 0);
       gal_tile_full_values_write(qprm.noerode_th, tl,
                                  !p->ignoreblankintiles,
-                                 p->qthreshname, NULL, PROGRAM_NAME);
+                                 p->qthreshname, NULL, 0);
       qprm.erode_th->name=qprm.noerode_th->name=NULL;
 
       if(qprm.expand_th)
@@ -663,18 +665,20 @@ threshold_quantile_find_apply(struct noisechiselparams *p)
           qprm.expand_th->name="QTHRESH_EXPAND";
           gal_tile_full_values_write(qprm.expand_th, tl,
                                      !p->ignoreblankintiles,
-                                     p->qthreshname, NULL, PROGRAM_NAME);
+                                     p->qthreshname, NULL, 0);
           qprm.expand_th->name=NULL;
         }
     }
 
 
   /* Remove the outliers. */
-  gal_tileinternal_no_outlier_local(qprm.erode_th, qprm.noerode_th,
-                                    qprm.expand_th, &cp->tl,
-                                    cp->interpmetric, cp->interpnumngb,
-                                    cp->numthreads, p->outliersclip,
-                                    p->outliersigma, p->qthreshname);
+  if(p->outliernumngb)
+    gal_tileinternal_no_outlier_local(qprm.erode_th, qprm.noerode_th,
+                                      qprm.expand_th, &cp->tl,
+                                      cp->interpmetric, p->outliernumngb,
+                                      cp->numthreads, p->outliersclip,
+                                      p->outliersigma, p->qthreshname,
+                                      "--outliernumngb");
 
 
   /* Use the no-outlier grid as a basis for later estimating the sky. To
@@ -712,7 +716,7 @@ threshold_quantile_find_apply(struct noisechiselparams *p)
   if(p->qthreshname && !tl->oneelempertile)
     {
       p->binary->name="QTHRESH-APPLIED";
-      gal_fits_img_write(p->binary, p->qthreshname, NULL, PROGRAM_NAME);
+      gal_fits_img_write(p->binary, p->qthreshname, NULL, 0);
       p->binary->name=NULL;
     }
 
