@@ -5,7 +5,7 @@ NoiseChisel is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -160,7 +160,7 @@ parse_opt(int key, char *arg, struct argp_state *state)
 {
   struct noisechiselparams *p = state->input;
 
-  /* Pass 'gal_options_common_params' into the child parser.  */
+  /* Pass 'gal_options_common_params' into the child parser. */
   state->child_inputs[0] = &p->cp;
 
   /* In case the user incorrectly uses the equal sign (for example
@@ -219,10 +219,10 @@ parse_opt(int key, char *arg, struct argp_state *state)
 /**************************************************************/
 /***************       Sanity Check         *******************/
 /**************************************************************/
-/* Read and check ONLY the options. When arguments are involved, do the
-   check in 'ui_check_options_and_arguments'. */
+/* Check ONLY the options. When arguments are involved, do the check
+   in 'ui_check_options_and_arguments'. */
 static void
-ui_read_check_only_options(struct noisechiselparams *p)
+ui_check_only_options(struct noisechiselparams *p)
 {
   /* If the convolved option is given, then the convolved HDU is also
      mandatory. */
@@ -253,10 +253,7 @@ ui_read_check_only_options(struct noisechiselparams *p)
   /* Kernel checks. */
   if(p->kernelname && strcmp(p->kernelname, UI_NO_CONV_KERNEL_NAME))
     {
-      /* Check if it exists. */
-      gal_checkset_check_file(p->kernelname);
-
-      /* If its FITS, see if a HDU has been provided. */
+      /* If it is FITS, see if a HDU has been provided. */
       if( gal_fits_file_recognized(p->kernelname) && p->khdu==NULL )
         error(EXIT_FAILURE, 0, "no HDU specified for kernel. When the "
               "kernel is a FITS file, a HDU must also be specified. You "
@@ -268,10 +265,7 @@ ui_read_check_only_options(struct noisechiselparams *p)
   /* Wide kernel checks. */
   if(p->widekernelname)
     {
-      /* Check if it exists. */
-      gal_checkset_check_file(p->widekernelname);
-
-      /* If its FITS, see if a HDU has been provided. */
+      /* If it is FITS, see if a HDU has been provided. */
       if( gal_fits_file_recognized(p->widekernelname) && p->whdu==NULL )
         error(EXIT_FAILURE, 0, "no HDU specified for the given wide kernel "
               "('%s'). When the wide kernel is a FITS file, a HDU must also "
@@ -287,7 +281,7 @@ ui_read_check_only_options(struct noisechiselparams *p)
      wanted a false detection rate of 0.0001 (a super-high value!), and
      instead of inputing 0.9999, we mistakenly gave '--snquant' a value of
      '0.0001'. We were thus fully confused with the output (an extremely
-     low value) and thought its a bug, while it wasn't! */
+     low value) and thought it is a bug, while it wasn't! */
   if(p->snquant<0.1)
     error(EXIT_SUCCESS, 0, "\nWARNING: Value of '--snquant' ('-c') is "
           "%g. Note that this is not a contamination rate (where lower "
@@ -326,10 +320,7 @@ ui_check_options_and_arguments(struct noisechiselparams *p)
   /* Basic input file checks. */
   if(p->inputname)
     {
-      /* Check if it exists. */
-      gal_checkset_check_file(p->inputname);
-
-      /* If its FITS, see if a HDU has been provided. */
+      /* If it is FITS, see if a HDU has been provided. */
       if( gal_fits_file_recognized(p->inputname) && p->cp.hdu==NULL )
         error(EXIT_FAILURE, 0, "no HDU specified for input. When the input "
               "is a FITS file, a HDU must also be specified, you can use "
@@ -378,7 +369,7 @@ ui_set_output_names(struct noisechiselparams *p)
 
       /* When the output name is given (possibly with directory
          information), the check images will also be put in that same
-         directory.. */
+         directory. */
       p->cp.keepinputdir=1;
     }
   else
@@ -451,7 +442,7 @@ ui_prepare_kernel(struct noisechiselparams *p)
           /* Read the kernel into memory. */
           p->kernel=gal_fits_img_read_kernel(p->kernelname, p->khdu,
                                              p->cp.minmapsize,
-                                             p->cp.quietmmap);
+                                             p->cp.quietmmap, "--khdu");
 
           /* Make sure it has the same dimensions as the input. */
           if( p->kernel->ndim != p->input->ndim )
@@ -481,7 +472,8 @@ ui_prepare_kernel(struct noisechiselparams *p)
      ignore it. */
   if(p->widekernelname)
     p->widekernel=gal_fits_img_read_kernel(p->widekernelname, p->whdu,
-                                           p->cp.minmapsize, p->cp.quietmmap);
+                                           p->cp.minmapsize,
+                                           p->cp.quietmmap, "--whdu");
 }
 
 
@@ -532,7 +524,7 @@ ui_prepare_tiles(struct noisechiselparams *p)
 
 
   /* If the input has blank elements, then set teh appropriate flag for
-     each tile.*/
+     each tile. */
   if( p->input->flag & GAL_DATA_FLAG_HASBLANK )
     {
       gal_tile_block_blank_flag(tl->tiles,  p->cp.numthreads);
@@ -545,12 +537,12 @@ ui_prepare_tiles(struct noisechiselparams *p)
     {
       /* Large tiles. */
       check=gal_tile_block_check_tiles(ltl->tiles);
-      gal_fits_img_write(check, tl->tilecheckname, NULL, PROGRAM_NAME);
+      gal_fits_img_write(check, tl->tilecheckname, NULL, 0);
       gal_data_free(check);
 
       /* Small tiles. */
       check=gal_tile_block_check_tiles(tl->tiles);
-      gal_fits_img_write(check, tl->tilecheckname, NULL, PROGRAM_NAME);
+      gal_fits_img_write(check, tl->tilecheckname, NULL, 0);
       gal_data_free(check);
 
       /* If 'continueaftercheck' hasn't been called, abort NoiseChisel. */
@@ -609,10 +601,10 @@ ui_preparations_read_input(struct noisechiselparams *p)
   p->input = gal_array_read_one_ch_to_type(p->inputname, p->cp.hdu,
                                            NULL, GAL_TYPE_FLOAT32,
                                            p->cp.minmapsize,
-                                           p->cp.quietmmap);
+                                           p->cp.quietmmap, "--hdu");
   p->input->wcs = gal_wcs_read(p->inputname, p->cp.hdu,
                                p->cp.wcslinearmatrix, 0, 0,
-                               &p->input->nwcs);
+                               &p->input->nwcs, "--hdu");
   p->input->ndim=gal_dimension_remove_extra(p->input->ndim,
                                             p->input->dsize,
                                             p->input->wcs);
@@ -671,7 +663,7 @@ ui_preparations(struct noisechiselparams *p)
   /* Prepare the names of the outputs. */
   ui_set_output_names(p);
 
-  /* Read the input datasets and do the basic checks.*/
+  /* Read the input datasets and do the basic checks. */
   ui_preparations_read_input(p);
 
   /* If a convolved image was given, read it in. Otherwise, read the given
@@ -682,7 +674,8 @@ ui_preparations(struct noisechiselparams *p)
       p->conv = gal_array_read_one_ch_to_type(p->convolvedname, p->chdu,
                                               NULL, GAL_TYPE_FLOAT32,
                                               p->cp.minmapsize,
-                                              p->cp.quietmmap);
+                                              p->cp.quietmmap,
+                                              "--chdu");
 
       /* Make sure the convolved image is the same size as the input. */
       if( gal_dimension_is_different(p->input, p->conv) )
@@ -694,7 +687,7 @@ ui_preparations(struct noisechiselparams *p)
   else
     ui_prepare_kernel(p);
 
-  /* Check for blank values to help later processing.  */
+  /* Check for blank values to help later processing. */
   gal_blank_present(p->input, 1);
 
   /* Prepare the tessellation. */
@@ -751,7 +744,7 @@ ui_read_check_inputs_setup(int argc, char *argv[],
 #include "args.h"
 
 
-  /* Initialize the options and necessary information.  */
+  /* Initialize the options and necessary information. */
   ui_initialize_options(p, program_options, gal_commonopts_options);
 
 
@@ -765,9 +758,8 @@ ui_read_check_inputs_setup(int argc, char *argv[],
   gal_options_read_config_set(&p->cp);
 
 
-  /* Read the options into the program's structure, and check them and
-     their relations prior to printing. */
-  ui_read_check_only_options(p);
+  /* Sanity check only on options. */
+  ui_check_only_options(p);
 
 
   /* Print the option values if asked. Note that this needs to be done
