@@ -8,8 +8,9 @@
 #     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 # All author(s):
 #     Mohammad Akhlaghi <mohammad@akhlaghi.org>
+#     Raul Infante-Sainz <infantesainz@gmail.com>
 #     Sepideh Eskandarlou <sepideh.eskandarlou@gmail.com>
-# Copyright (C) 2020-2023 Free Software Foundation, Inc.
+# Copyright (C) 2020-2024 Free Software Foundation, Inc.
 #
 # Gnuastro is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free
@@ -45,6 +46,8 @@ ds9mode=""
 ds9scale=""
 ds9extra=""
 ds9center=""
+ds9region=""
+globalhdu=""
 ds9geometry=""
 version=@VERSION@
 ds9colorbarmulti=""
@@ -88,15 +91,17 @@ experienced Gnuastro users and developers. For more information, please run:
 $scriptname options:
  Input:
   -h, --hdu=STR           Extension name or number of input data.
+  -g, --globalhdu=STR     Use this HDU for all inputs, ignore '--hdu'.
 
  Output:
-  -g, --ds9geometry=INTxINT Size of DS9 window, e.g., for HD (800x1000) and
+  -G, --ds9geometry=INTxINT Size of DS9 window, e.g., for HD (800x1000) and
                           for 4K (1800x3000). If not given, the script will
                           attempt to find your screen resolution and find a
                           good match, otherwise, use the default size.
   -e, --ds9extra=STR      Extra options to pass to DS9 after default ones.
   -s, --ds9scale=STR      Custom value to '-scale' option in DS9.
   -c, --ds9center=FLT,FLT Coordinates of center in shown DS9 window.
+  -r, --ds9region=STR[,...] DS9 region(s) to load.
   -O, --ds9mode=img/wcs   Coord system to interpret '--ds9center' (img/wcs).
   -m, --ds9colorbarmulti  Separate color bars for each loaded image.
   -p, --prefix=STR        Directory containing DS9 or TOPCAT executables.
@@ -124,7 +129,7 @@ EOF
 print_version() {
     cat <<EOF
 $scriptname (GNU Astronomy Utilities) $version
-Copyright (C) 2020-2023 Free Software Foundation, Inc.
+Copyright (C) 2020-2024 Free Software Foundation, Inc.
 License GPLv3+: GNU General public license version 3 or later.
 This is free software: you are free to change and redistribute it.
 There is NO WARRANTY, to the extent permitted by law.
@@ -191,26 +196,32 @@ do
     case "$1" in
 
         # Input options
-        -h|--hdu)             hdu="$2";                            check_v "$1" "$hdu"; shift;shift;;
-        -h=*|--hdu=*)         hdu="${1#*=}";                       check_v "$1" "$hdu"; shift;;
-        -h*)                  hdu=$(echo "$1"  | sed -e's/-h//');  check_v "$1" "$hdu"; shift;;
+        -h|--hdu)            aux="$2";                             check_v "$1" "$aux"; hdu="$hdu $aux"; shift;shift;;
+        -h=*|--hdu=*)        aux="${1#*=}";                        check_v "$1" "$aux"; hdu="$hdu $aux"; shift;;
+        -h*)                 aux="$(echo "$1"  | sed -e's/-h//')"; check_v "$1" "$aux"; hdu="$hdu $aux"; shift;;
+        -g|--globalhdu)      aux="$2";                             check_v "$1" "$aux"; globalhdu="$aux"; shift;shift;;
+        -g=*|--globalhdu=*)  aux="${1#*=}";                        check_v "$1" "$aux"; globalhdu="$aux"; shift;;
+        -g*)                 aux="$(echo "$1"  | sed -e's/-g//')"; check_v "$1" "$aux"; globalhdu="$aux"; shift;;
 
         # Output options
-        -g|--ds9geometry)     ds9geometry="$2";                    check_v "$1" "$ds9geometry"; shift;shift;;
-        -g=*|--ds9geometry=*) ds9geometry="${1#*=}";               check_v "$1" "$ds9geometry"; shift;;
-        -g*)                  ds9geometry=$(echo "$1"  | sed -e's/-g//');  check_v "$1" "$ds9geometry"; shift;;
+        -G|--ds9geometry)     ds9geometry="$2";                    check_v "$1" "$ds9geometry"; shift;shift;;
+        -G=*|--ds9geometry=*) ds9geometry="${1#*=}";               check_v "$1" "$ds9geometry"; shift;;
+        -G*)                  ds9geometry=$(echo "$1"  | sed -e's/-G//');  check_v "$1" "$ds9geometry"; shift;;
         -s|--ds9scale)        ds9scale="$2";                       check_v "$1" "$ds9scale"; shift;shift;;
         -s=*|--ds9scale=*)    ds9scale="${1#*=}";                  check_v "$1" "$ds9scale"; shift;;
         -s*)                  ds9scale=$(echo "$1"  | sed -e's/-s//');  check_v "$1" "$ds9scale"; shift;;
         -e|--ds9extra)        ds9extratmp="$2";                    check_v "$1" "$ds9extratmp"; shift;shift;;
         -e=*|--ds9extra=*)    ds9extratmp="${1#*=}";               check_v "$1" "$ds9extratmp"; shift;;
-        -e*)                  ds9extratmp=$(echo "$1"  | sed -e's/-s//');  check_v "$1" "$ds9extratmp"; shift;;
+        -e*)                  ds9extratmp=$(echo "$1"  | sed -e's/-e//');  check_v "$1" "$ds9extratmp"; shift;;
         -c|--ds9center)       ds9center="$2";                      check_v "$1" "$ds9center"; shift;shift;;
         -c=*|--ds9center=*)   ds9center="${1#*=}";                 check_v "$1" "$ds9center"; shift;;
-        -c*)                  ds9center=$(echo "$1"  | sed -e's/-s//');  check_v "$1" "$ds9center"; shift;;
+        -c*)                  ds9center=$(echo "$1"  | sed -e's/-c//');  check_v "$1" "$ds9center"; shift;;
+        -r|--ds9region)       ds9region="$2";                      check_v "$1" "$ds9region"; shift;shift;;
+        -r=*|--ds9region=*)   ds9region="${1#*=}";                 check_v "$1" "$ds9region"; shift;;
+        -r*)                  ds9region=$(echo "$1"  | sed -e's/-r//');  check_v "$1" "$ds9region"; shift;;
         -O|--ds9mode)         ds9mode="$2";                       check_v "$1" "$ds9mode"; shift;shift;;
         -O=*|--ds9mode=*)     ds9mode="${1#*=}";                  check_v "$1" "$ds9mode"; shift;;
-        -O*)                  ds9mode=$(echo "$1"  | sed -e's/-s//');  check_v "$1" "$ds9mode"; shift;;
+        -O*)                  ds9mode=$(echo "$1"  | sed -e's/-O//');  check_v "$1" "$ds9mode"; shift;;
         -m|--ds9colorbarmulti)    ds9colorbarmulti=1; shift;;
         -m*|--ds9colorbarmulti=*) on_off_option_error --ds9colorbarmulti -m;;
         -p|--prefix)          prefix="$2";                         check_v "$1" "$prefix"; shift;shift;;
@@ -280,6 +291,18 @@ EOF
     fi
 fi
 
+# If HDUs are given, make sure they are the same number as images.
+if ! [ x"$hdu" = x ]; then
+    nhdu=$(echo $hdu | wc -w)
+    nin=$(echo $inputs | wc -w)
+    if [ $nhdu -lt $nin  ]; then
+        cat <<EOF
+$scriptname: number of input HDUs (values to '--hdu' or '-h') is less than the number of inputs. If all the HDUs are the same, you can use the '--globalhdu' or '-g' option
+EOF
+        exit 1
+    fi
+fi
+
 
 
 
@@ -300,7 +323,13 @@ if [ x"$ds9geometry" = x ]; then
                         | awk 'NR==1{w=0.75*$2; printf "%dx%d\n", w, $2}')
     fi
 fi
-ds9geoopt="-geometry $ds9geometry"
+
+# It can happen that 'ds9geometry' is still an empty string (the command to
+# read the geometry could have failed on the host operating system), in
+# such cases, we should just ignore this option.
+if ! [ x"$ds9geometry" = x ]; then
+    ds9geoopt="-geometry $ds9geometry"
+fi
 
 
 
@@ -327,6 +356,15 @@ ds9scaleopt="-scale $ds9scale"
 
 
 
+#Set the DS9 region(s) to load.
+if [ ! x"$ds9region" = x ]; then
+  ds9region="-region "$(echo $ds9region | sed 's/,/ -region /g')
+fi
+
+
+
+
+
 # Set the DS9 pan option.
 ds9pan=""
 if [ x"$ds9center" != x ]; then
@@ -356,6 +394,18 @@ fi
 
 
 
+# Color map contrast and bias for the default SLS color map designed to
+# make the color of the largest value red, not white (which is the color of
+# the default background). These are currently not configurable because
+# generally, the colormap ('sls') is not yet configurable.
+cmap=sls
+cmap_bias=0.5634
+cmap_contrast=0.8955
+
+
+
+
+
 # To allow generic usage, if no input file is given (the `if' below is
 # true), then just open an empty ds9.
 if [ x"$inputs" = x ]; then
@@ -376,13 +426,22 @@ else
             # If the file was a image, then  `check` will be 1.
             if [ "$type" = 1 ]; then
 
-                # If a HDU is given, add it to all the input file names (within
-                # square brackets for DS9).
-                if [ x"$hdu" = x ]; then
+                # If a HDU is given, add it to all the input file names
+                # (within square brackets for DS9).
+                if [ x"$hdu" = x ] && [ x"$globalhdu" = x ]; then
                     inwithhdu="$inputs"
                 else
+                    c=1
                     inwithhdu=""
-                    for i in $inputs; do inwithhdu="$inwithhdu $i[$hdu]"; done
+                    for i in $inputs; do
+                        if [ x"$hdu" = x ]; then
+                            h="$globalhdu"
+                        else
+                            h=$(echo $hdu | awk -vc=$c '{print $c}')
+                        fi
+                        inwithhdu="$inwithhdu $i[$h]"
+                        c=$((c+1))
+                    done
                 fi
 
                 # Read the number of dimensions.
@@ -418,7 +477,8 @@ else
                                      $inwithhdu \
                                      -zoom to fit \
                                      -wcs degrees \
-                                     -cmap sls \
+                                     -cmap $cmap \
+                                     -cmap $cmap_contrast $cmap_bias \
                                      -match frame image \
                                      -match frame colorbar \
                                      -frame lock image \
@@ -426,6 +486,7 @@ else
                                      -view multi $multicolorbars \
                                      -lock slice image \
                                      $ds9pan \
+                                     $ds9region \
                                      $ds9extra"
                 else
 
@@ -453,6 +514,7 @@ else
                                      -colorbar lock yes \
                                      -view multi $multicolorbars \
                                      $ds9pan \
+                                     $ds9region \
                                      $ds9extra"
                 fi
 
@@ -464,8 +526,13 @@ else
                 if [ x"$hdu" = x ]; then
                 inwithhdu="$inputs"
                 else
+                    c=1
                     inwithhdu=""
-                    for i in $inputs; do inwithhdu="$inwithhdu $i#$hdu"; done
+                    for i in $inputs; do
+                        h=$(echo $hdu | awk -vc=$c '{print $c}')
+                        inwithhdu="$inwithhdu $i#$h"
+                        c=$((c+1))
+                    done
                 fi
 
                 # TOPCAT command.
