@@ -40,6 +40,7 @@ export LC_NUMERIC=C
 # Default option values (can be changed with options on the command-line).
 hdu=1
 rmax=""
+polar=0
 quiet=""
 instd=""
 stdhdu=1
@@ -113,6 +114,7 @@ $scriptname options:
   -Q, --axis-ratio=FLT     Axis ratio for ellipse profiles (A/B).
   -a, --azimuth=FLT,FLT    Azimuthal angles range (from the major axis).
   -p, --position-angle=FLT Position angle for ellipse profiles.
+  -g, --polar              Polar plot (azimuth angle vs. radius).
   -s, --sigmaclip=FLT,FLT  Sigma-clip multiple and tolerance.
   -z, --zeropoint=FLT      Zeropoint magnitude of input dataset.
   -Z, --zeroisnotblank     0.0 in float or double images are not blank.
@@ -122,7 +124,7 @@ $scriptname options:
   -t, --tmpdir             Directory to keep temporary files.
   -k, --keeptmp            Keep temporal/auxiliar files.
   -m, --measure=STR        Measurement operator (mean, sigclip-mean, etc.).
-  -P, --precision=INT      Number of digits after the decimal point for radius.
+  -P, --precision=INT      Number of digits after decimal point for radius.
   -v, --oversample=INT     Oversample for higher resolution radial profile.
   -u, --undersample=INT    Undersample for lower resolution radial profile.
   -i, --instd=FLT/STR      Sky standard deviation per pixel, as a single
@@ -193,6 +195,27 @@ Paper introducing this script
         adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }
 
+Paper introducing the --polar option
+------------------------------------
+  @ARTICLE{2024RNAAS...8..168E,
+         author = {{Eskandarlou}, Sepideh and {Akhlaghi}, Mohammad},
+          title = "{Gnuastro: Generating Polar Plots in Astronomical Images}",
+        journal = {Research Notes of the American Astronomical Society},
+       keywords = {Astronomy software, Open source software, Astronomical techniques, Spiral pitch angle, Spiral arms, 1855, 1866, 1684, 1561, 1559, Astrophysics - Instrumentation and Methods for Astrophysics, Astrophysics - Astrophysics of Galaxies},
+           year = 2024,
+          month = jun,
+         volume = {8},
+         number = {6},
+            eid = {168},
+          pages = {168},
+            doi = {10.3847/2515-5172/ad5a6c},
+  archivePrefix = {arXiv},
+         eprint = {2406.14619},
+   primaryClass = {astro-ph.IM},
+         adsurl = {https://ui.adsabs.harvard.edu/abs/2024RNAAS...8..168E},
+        adsnote = {Provided by the SAO/NASA Astrophysics Data System}
+  }
+
 Paper introducing Gnuastro (currently main citation)
 ----------------------------------------------------
   @ARTICLE{gnuastro,
@@ -212,6 +235,8 @@ Paper introducing Gnuastro (currently main citation)
     adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }
 
+
+
 Acknowledgement
 ---------------
 This work was partly done using GNU Astronomy Utilities (Gnuastro, ascl.net/1801.009) version $version. Work on Gnuastro has been funded by the Japanese Ministry of Education, Culture, Sports, Science, and Technology (MEXT) scholarship and its Grant-in-Aid for Scientific Research (21244012, 24253003), the European Research Council (ERC) advanced grant 339659-MUSICOS, the Spanish Ministry of Economy and Competitiveness (MINECO, grant number AYA2016-76219-P) and the NextGenerationEU grant through the Recovery and Resilience Facility project ICTS-MRR-2021-03-CEFCA.
@@ -286,33 +311,35 @@ while [ $# -gt 0 ]
 do
     case "$1" in
         # Input parameters.
-        -h|--hdu)           hdu="$2";                                  check_v "$1" "$hdu";  shift;shift;;
-        -h=*|--hdu=*)       hdu="${1#*=}";                             check_v "$1" "$hdu";  shift;;
-        -h*)                hdu=$(echo "$1"  | sed -e's/-h//');        check_v "$1" "$hdu";  shift;;
-        -O|--mode)          mode="$2";                                 check_v "$1" "$mode";  shift;shift;;
-        -O=*|--mode=*)      mode="${1#*=}";                            check_v "$1" "$mode";  shift;;
-        -O*)                mode=$(echo "$1"  | sed -e's/-O//');       check_v "$1" "$mode";  shift;;
-        -c|--center)        center="$2";                               check_v "$1" "$center";  shift;shift;;
-        -c=*|--center=*)    center="${1#*=}";                          check_v "$1" "$center";  shift;;
-        -c*)                center=$(echo "$1"  | sed -e's/-c//');     check_v "$1" "$center";  shift;;
-        -R|--rmax)          rmax="$2";                                 check_v "$1" "$rmax";  shift;shift;;
-        -R=*|--rmax=*)      rmax="${1#*=}";                            check_v "$1" "$rmax";  shift;;
-        -R*)                rmax=$(echo "$1"  | sed -e's/-R//');       check_v "$1" "$rmax";  shift;;
-        -Q|--axis-ratio)     axisratio="$2";                            check_v "$1" "$axisratio";  shift;shift;;
-        -Q=*|--axis-ratio=*) axisratio="${1#*=}";                       check_v "$1" "$axisratio";  shift;;
-        -Q*)                 axisratio=$(echo "$1"  | sed -e's/-Q//');  check_v "$1" "$axisratio";  shift;;
-        -a|--azimuth)       azimuth="$2";                               check_v "$1" "$azimuth";  shift;shift;;
-        -a=*|--azimuth=*)   azimuth="${1#*=}";                          check_v "$1" "$azimuth";  shift;;
-        -a*)                azimuth=$(echo "$1"  | sed -e's/-a//');     check_v "$1" "$azimuth";  shift;;
-        -p|--position-angle)     positionangle="$2";                        check_v "$1" "$positionangle";  shift;shift;;
-        -p=*|--position-angle=*) positionangle="${1#*=}";               check_v "$1" "$positionangle";  shift;;
+        -h|--hdu)                hdu="$2";                                     check_v "$1" "$hdu";  shift;shift;;
+        -h=*|--hdu=*)            hdu="${1#*=}";                                check_v "$1" "$hdu";  shift;;
+        -h*)                     hdu=$(echo "$1"  | sed -e's/-h//');           check_v "$1" "$hdu";  shift;;
+        -O|--mode)               mode="$2";                                    check_v "$1" "$mode";  shift;shift;;
+        -O=*|--mode=*)           mode="${1#*=}";                               check_v "$1" "$mode";  shift;;
+        -O*)                     mode=$(echo "$1"  | sed -e's/-O//');          check_v "$1" "$mode";  shift;;
+        -c|--center)             center="$2";                                  check_v "$1" "$center";  shift;shift;;
+        -c=*|--center=*)         center="${1#*=}";                             check_v "$1" "$center";  shift;;
+        -c*)                     center=$(echo "$1"  | sed -e's/-c//');        check_v "$1" "$center";  shift;;
+        -R|--rmax)               rmax="$2";                                    check_v "$1" "$rmax";  shift;shift;;
+        -R=*|--rmax=*)           rmax="${1#*=}";                               check_v "$1" "$rmax";  shift;;
+        -R*)                     rmax=$(echo "$1"  | sed -e's/-R//');          check_v "$1" "$rmax";  shift;;
+        -Q|--axis-ratio)         axisratio="$2";                               check_v "$1" "$axisratio";  shift;shift;;
+        -Q=*|--axis-ratio=*)     axisratio="${1#*=}";                          check_v "$1" "$axisratio";  shift;;
+        -Q*)                     axisratio=$(echo "$1"  | sed -e's/-Q//');     check_v "$1" "$axisratio";  shift;;
+        -a|--azimuth)            azimuth="$2";                                 check_v "$1" "$azimuth";  shift;shift;;
+        -a=*|--azimuth=*)        azimuth="${1#*=}";                            check_v "$1" "$azimuth";  shift;;
+        -a*)                     azimuth=$(echo "$1"  | sed -e's/-a//');       check_v "$1" "$azimuth";  shift;;
+        -p|--position-angle)     positionangle="$2";                           check_v "$1" "$positionangle";  shift;shift;;
+        -p=*|--position-angle=*) positionangle="${1#*=}";                      check_v "$1" "$positionangle";  shift;;
         -p*)                     positionangle=$(echo "$1"  | sed -e's/-p//'); check_v "$1" "$positionangle";  shift;;
-        -s|--sigmaclip)     sigmaclip="$2";                            check_v "$1" "$sigmaclip";  shift;shift;;
-        -s=*|--sigmaclip=*) sigmaclip="${1#*=}";                       check_v "$1" "$sigmaclip";  shift;;
-        -s*)                sigmaclip=$(echo "$1"  | sed -e's/-s//');  check_v "$1" "$sigmaclip";  shift;;
-        -z|--zeropoint)     zeropoint="$2";                            check_v "$1" "$zeropoint";  shift;shift;;
-        -z=*|--zeropoint=*) zeropoint="${1#*=}";                       check_v "$1" "$zeropoint";  shift;;
-        -z*)                zeropoint=$(echo "$1"  | sed -e's/-z//');  check_v "$1" "$zeropoint";  shift;;
+        -s|--sigmaclip)          sigmaclip="$2";                               check_v "$1" "$sigmaclip";  shift;shift;;
+        -s=*|--sigmaclip=*)      sigmaclip="${1#*=}";                          check_v "$1" "$sigmaclip";  shift;;
+        -s*)                     sigmaclip=$(echo "$1"  | sed -e's/-s//');     check_v "$1" "$sigmaclip";  shift;;
+        -z|--zeropoint)          zeropoint="$2";                               check_v "$1" "$zeropoint";  shift;shift;;
+        -z=*|--zeropoint=*)      zeropoint="${1#*=}";                          check_v "$1" "$zeropoint";  shift;;
+        -z*)                     zeropoint=$(echo "$1"  | sed -e's/-z//');     check_v "$1" "$zeropoint";  shift;;
+        -g|--polar)              polar=1; shift;;
+        -g*|--polar=*)           on_off_option_error --polar -g;;
 
         # Output parameters
         -k|--keeptmp)     keeptmp=1; shift;;
@@ -395,9 +422,7 @@ if [ x"$center" != x ]; then
                                   {for(i=1;i<=NF;++i) c+=$i!=""} \
                                   END{print c}')
     if [ x$ncenter != x2 ]; then
-        cat <<EOF
-$scriptname: '--center' (or '-c') only takes two values, but $ncenter were given in 'center'
-EOF
+        echo "$scriptname: '--center' (or '-c') only takes two values, but $ncenter were given in '$center'"
         exit 1
     fi
 fi
@@ -434,6 +459,21 @@ fi
 # If no specific measurement has been requested, use the mean.
 if [ x"$measure" = x ]; then measure=mean; fi
 
+# Without azimuthal angle, we can not create a polar-plot.
+if [ x"$azimuth" = x ] && [ x$polar = x1 ]; then
+    azimuth="0,360"
+fi
+
+# If the user call the '--undersample' and '--oversample' option. On the
+# other hand, they use '--polar' option with these options
+if [ x$polar = x1 ] && [ x"$undersample" != x ] ; then
+    echo "$scriptname: the polar plot does not yet support --undersample; please get in touch with us at 'bug-gnuastro@gnu.org' for its possible addition"; exit 1
+fi
+
+if [ x$polar = x1 ] && [ x"$oversample" != x ] ; then
+    echo "$scriptname: the polar plot does not yet support --oversample; please get in touch with us at 'bug-gnuastro@gnu.org' for its possible addition"; exit 1
+fi
+
 
 
 
@@ -679,7 +719,7 @@ echo "1 $xcenter $ycenter 7 $rmax 1 $positionangle $axisratio 1 1" \
                  --circumwidth=1 --replace --output=$radialaperturesholed
 astarithmetic $radialaperturesholed set-i \
               i 0 ne 1 fill-holes set-good \
-              i good i 1 + where $precfactor x uint32\
+              i good i 1 + where $precfactor x uint32 \
               $quiet --output $radialapertures
 rm $radialaperturesholed
 
@@ -700,9 +740,22 @@ aperturesrawbase=apertures-raw.fits
 aperturesraw=$tmpdir/$aperturesrawbase
 if [ x"$azimuth" != x ]; then
 
+    # Function to normalize angles to the range [0, 360) For example, if
+    # --azimuth=337,367, then the angle to be used should be azimuth=337,7.
+    # Here, this conversion is done. Negative angles are also considered.
+    transform_angle() {
+        angle=$1
+        new_angle=$(awk "BEGIN { print ($angle % 360 + 360) % 360 }")
+        echo $new_angle
+    }
+
     # Get the initial and final azimuth angles
-    azimuth_ini=$(echo "$azimuth" | awk 'BEGIN{FS=","} {print $1}')
-    azimuth_fin=$(echo "$azimuth" | awk 'BEGIN{FS=","} {print $2}')
+    raw_azimuth_ini=$(echo "$azimuth" | awk 'BEGIN{FS=","} {print $1}')
+    raw_azimuth_fin=$(echo "$azimuth" | awk 'BEGIN{FS=","} {print $2}')
+
+    # Transform the azimuth angles to [0, 360) range
+    azimuth_ini=$(transform_angle $raw_azimuth_ini)
+    azimuth_fin=$(transform_angle $raw_azimuth_fin)
 
     # Generate the azimuthal apertures
     azimuthaperturesbase=azimuth-raw.fits
@@ -723,7 +776,7 @@ if [ x"$azimuth" != x ]; then
     #     the regions of each angle so the user gets the region between the
     #     two angles.
     #
-    #   - The first is smaller than the second (for example
+    #   - The first is greater than the second (for example
     #     '--azimuth=355,5') In this case, we assume that the user wants an
     #     azimuthal range outside the two angles. In the example above, its
     #     the 10 degrees around the azimuthal angle 0. For this case, we
@@ -742,10 +795,10 @@ if [ x"$azimuth" != x ]; then
                      | awk ' {if ($1<$2) print "and"; \
                               else       print "or"}')
     astarithmetic --output=$aperturesraw $quiet \
-                  $radialapertures  -h1 set-radial \
-                  $azimuthapertures -h1 set-azimuth \
-                  azimuth $azimuth_ini ge \
-                  azimuth $azimuth_fin le $condition \
+                  $radialapertures  -h1 uint32 set-radial \
+                  $azimuthapertures -h1 uint16 set-azimuth \
+                  azimuth $azimuth_ini uint16 ge \
+                  azimuth $azimuth_fin uint16 le $condition \
                   radial 1 eq or set-arc \
                   radial arc 1 uint8 ne 0 uint8 where
 else
@@ -756,6 +809,38 @@ fi
 
 
 
+# MakeCatalog configuration options
+# ---------------------------------
+#
+# If not given, don't use anything and just let MakeCatalog use its default
+# values.
+if [ x"$sigmaclip" = x ]; then finalsigmaclip=""
+else                           finalsigmaclip="--sigmaclip=$sigmaclip";
+fi
+if [ x"$zeropoint" = x ]; then finalzp=""
+else                           finalzp="--zeropoint=$zeropoint";
+fi
+if [ x$polar = x0 ]; then polaropt=""
+else
+    # We are using 'raw_azimuth_fin' because it can be set to zero when the
+    # value was 360. Note also that we should convert to an integer at the
+    # start (before 'set-i'), otherwise, in floating point, the 'gt'
+    # condition is going to miss the outer edge.
+    condition=$(echo $azimuth_ini $azimuth_fin \
+                     | awk ' {if ($1<$2) print "or"; \
+                              else       print "and"}')
+    intazimuthapertures=$tmpdir/azimuth-raw-int.fits
+    astarithmetic $azimuthapertures uint16 set-i i \
+                  i $azimuth_ini     uint16 lt \
+                  i $raw_azimuth_fin uint16 gt $condition \
+                  0 where uint32 --output=$intazimuthapertures $quiet
+    polaropt="--clumpsfile=$intazimuthapertures --clumpshdu=1 --clumpscat"
+fi
+
+
+
+
+
 # Undersampling the aperture image
 # --------------------------------
 #
@@ -801,22 +886,6 @@ finalmeasure=$(echo "$measure" \
 
 
 
-# MakeCatalog configuration options
-# ---------------------------------
-#
-# If not given, don't use anything and just let MakeCatalog use its default
-# values.
-if [ x"$sigmaclip" = x ]; then finalsigmaclip=""
-else                           finalsigmaclip="--sigmaclip=$sigmaclip";
-fi
-if [ x"$zeropoint" = x ]; then finalzp=""
-else                           finalzp="--zeropoint=$zeropoint";
-fi
-
-
-
-
-
 # Obtain the radial profile
 # -------------------------
 #
@@ -840,9 +909,10 @@ fi
 #   the center, but after adding this, the '--sb-error' column was nicely
 #   consistent with the scatter in the mock profiles at central radii.
 cat=$tmpdir/catalog.fits
-astmkcatalog $apertures --hdu=1 --valuesfile=$values --valueshdu=1 --ids \
-             $finalinstd $finalmeasure $finalsigmaclip $finalzp \
-	     --spatialresolution=0.0 --output=$cat $quiet
+astmkcatalog $apertures --hdu=1 --valuesfile=$values --valueshdu=1 \
+             --ids $finalinstd $finalmeasure $finalsigmaclip $finalzp \
+             $polaropt --spatialresolution=0.0 --output=$cat $quiet
+
 
 
 
@@ -857,8 +927,9 @@ astmkcatalog $apertures --hdu=1 --valuesfile=$values --valueshdu=1 --ids \
 radraw=$tmpdir/radii.fits
 if [ x"$oversample" != x ]; then
 
-    asttable $cat -c'arith OBJ_ID float32 '$precfactor' / 1 - '$oversample' /' \
-             -o$radraw --colmetadata=1,RADIUS,pix,"Radial distance"
+    asttable $cat -o$radraw \
+             --colmetadata=1,RADIUS,pix,"Radial distance" \
+             -c'arith OBJ_ID float32 '$precfactor' / 1 - '$oversample' /'
 
 elif [ x"$undersample" != x ]; then
 
@@ -878,6 +949,7 @@ fi
 
 
 
+
 # Prepare the final output columns
 # --------------------------------
 #
@@ -904,7 +976,132 @@ asttable $radraw --catcolumnfile=$cat $restcols --output=$outraw \
 # MakeCatalog). Therefore, once the final radii are set (accounting for
 # over/under sampling), we should make sure that the final output doesn't
 # contain radii larger than what the user asked for.
-asttable $outraw --range=RADIUS,0,$rmax --output=$output
+#
+# We are not using '$output' here, because the user may have asked to make
+# a polar plot and we may confront some bugs in the middle. It is better
+# that the final output only be built after everything is complete.
+#
+# When a polar plot is not requested, we can immediately write the output,
+# otherwise, we need to add a second HDU, so we will not write the final
+# output yet.
+if [ x$polar = x0 ]; then outputraw=$output
+else
+    osuffix=$(echo $output | awk 'BEGIN{FS="."}{print $NF}')
+    outputraw=$tmpdir/output.$osuffix
+fi
+asttable $outraw --range=RADIUS,0,$rmax --output=$outputraw
+
+
+
+
+
+# Polar plot
+# ----------
+#
+# Generate the polar plot if it was requested.
+if [ x$polar = x1 ]; then
+
+    # Set metadata on the polar-plot catalog for easy operations below (and
+    # for debugging). To include the maximum radius (99 in case of
+    # '--rmax=100'), because Table's '--range' option doesn't include the
+    # maximum number and we are dealing with integers, we need to add
+    # 'rmax' with one.
+    polarcat=$tmpdir/polar-catalog.fits
+    rmaxpone=$(astarithmetic $rmax uint32 1 + --quiet)
+    asttable $cat -hCLUMPS --range=HOST_OBJ_ID,0,$rmaxpone \
+             --colmetadata=HOST_OBJ_ID,RADIUS,pix,"Radial distance" \
+             --colmetadata=ID_IN_HOST_OBJ,AZIMUTH,degree,"Azimuth angle" \
+             --output=$polarcat
+
+    # Find the maximum value of radius and azimuth angel.
+    maxrad=$(aststatistics  $polarcat -h1 -cRADIUS  --maximum)
+    maxazim=$(aststatistics $polarcat -h1 -cAZIMUTH --maximum)
+    minazim=$(aststatistics $polarcat -h1 -cAZIMUTH --minimum)
+
+    # In the end, many azimuth angles close to radius zero are not going to
+    # be filled at all! We need to set those to NaN within the radial
+    # profile script (because there was no data there and we want to
+    # preserve the zero-valued pixels in our radial profiles). So here
+    # (before calling MakeProfiles), we replace any possible zeros in the
+    # input table with a pre-defined number (the maximum value in the image
+    # plus one), and later, rever this specific number back to zero.
+    polarcatz=$tmpdir/polar-catalog-no-zeros.fits
+    numzero=$(asttable $polarcat --equal=3,0 | wc -l)
+    if [ $numzero = 0 ]; then
+        ln -sf $polarcat $polarcatz
+    else
+        maxmesure=$(aststatistics $polarcat -h1 -c3 --maximum -q)
+        placeholder=$(astarithmetic $maxmesure 1 + -q)
+        asttable $polarcat -cRADIUS,AZIMUTH --output=$polarcatz \
+                 -c'arith $3 set-m m m 0 eq '$placeholder' where'
+    fi
+
+    # Generate the raw polar plot. When the user sets a non-zero minimum
+    # azimuthal angle, we need the full range of azimuthal angles here, so
+    # the azimuthal width is effectively just the maximum azimuthal
+    # angle. If the minimum is non-zero, we will later crop the output to
+    # remove the all-zero columns of the output image.
+    ppraw=$tmpdir/polar-plot-raw.fits
+    asttable $polarcat -h1 -cAZIMUTH,RADIUS,3  \
+        | awk '{print(1, $1, $2, 4, 0, 0, 0, 0, $3, 0)}' \
+        | astmkprof --mforflatpix --mode=img --oversample=1 \
+                    --mergedsize=$maxazim,$maxrad --clearcanvas \
+                    --output=$ppraw $quiet \
+                    --crpix=1,1 \
+                    --pc=1,0,0,1 \
+                    --cdelt=1,1 \
+                    --cunit=deg,pix \
+                    --ctype=AZI,RAD \
+                    --crval=1,0
+
+    # If the minimum azimuthal angle is not zero, then we need to crop the
+    # zero-valued regions (as described above).
+    ppcrop=$tmpdir/polar-plot-crop.fits
+    if [ $minazim = 0 ]; then
+        ln -sf $ppraw $ppcrop
+    else
+        astcrop $ppraw --mode=img --section=$minazim:$maxazim,: \
+                --output=$ppcrop $quiet
+    fi
+
+    # Any zero-valued pixel in the output of MakeProfiles means that there
+    # was no input data there so we should set them to Nan! Recall that
+    # above, if there was any actual zeros, they were replaced and we set
+    # them back to zero after setting the NaNs.
+    ppout=$tmpdir/polar-plot.fits
+    if  [ $numzero = 0 ]; then
+        astarithmetic $ppcrop set-p p p 0 eq nan where \
+                      --output=$ppout $quiet
+    else
+        astarithmetic $ppcrop                       set-p \
+                      p p 0            eq nan where set-z \
+                      z z $placeholder eq 0   where \
+                      --output=$ppout $quiet
+    fi
+
+    # If the output is a FITS file, then add a new HDU. Otherwise (for
+    # example output is plain-text), we need to make a new file.
+    if astfits $outputraw &> /dev/null; then
+        exthdu=2
+        polarfile=$outputraw
+    else
+        # Set its properties.
+        exthdu=1
+        polarfile=$(echo $output | sed -e's|.'$osuffix'|-polar.fits|')
+
+        # In case it already exists, delete it (because we later
+        # "--copy"). Recall that we are in the scenario that the actual
+        # radial profile was not FITS.
+        if [ -f $polarfile ]; then rm $polarfile; fi
+    fi
+
+    # Copy the image into the desired output file and set its HDU name.
+    astfits $ppout --copy=1 --output=$polarfile
+    astfits $polarfile --hdu=$exthdu --update=EXTNAME,POLAR-PLOT
+
+    # Copy the 'rawoutput' into the final output.
+    cp $outputraw $output
+fi
 
 
 
