@@ -5,7 +5,7 @@ Statistics is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2022 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -55,9 +55,10 @@ sky_on_thread(void *in_prm)
 
   void *tblock=NULL, *tarray=NULL;
   int stype=p->sky_t->type, itype=p->input->type;
-  gal_data_t *num, *tile, *mean, *meanquant, *sigmaclip;
+  gal_data_t *num, *tile, *mean, *meanquant, *clip;
   size_t i, tind, twidth=gal_type_sizeof(p->sky_t->type);
-
+  uint8_t mclipflags = ( GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_MEAN
+                         | GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_STD );
 
   /* Find the Sky and its standard deviation on the tiles given to this
      thread. */
@@ -97,19 +98,24 @@ sky_on_thread(void *in_prm)
           /* Get the sigma-clipped mean and standard deviation. 'inplace'
              is irrelevant here because this is a tile and it will be
              copied anyway. */
-          sigmaclip=gal_statistics_sigma_clip(tile, p->sclipparams[0],
-                                              p->sclipparams[1], 1, 1);
+          clip=gal_statistics_clip_sigma(tile, p->sclipparams[0],
+                                         p->sclipparams[1], mclipflags,
+                                         1, 1);
 
           /* Put the mean and its standard deviation into the respective
              place for this tile. */
-          sigmaclip=gal_data_copy_to_new_type_free(sigmaclip, stype);
+          clip=gal_data_copy_to_new_type_free(clip, stype);
           memcpy(gal_pointer_increment(p->sky_t->array, tind, stype),
-                 gal_pointer_increment(sigmaclip->array, 2, stype), twidth);
+                 gal_pointer_increment(clip->array,
+                                       GAL_STATISTICS_CLIP_OUTCOL_MEAN,
+                                       stype), twidth);
           memcpy(gal_pointer_increment(p->std_t->array, tind, stype),
-                 gal_pointer_increment(sigmaclip->array, 3, stype), twidth);
+                 gal_pointer_increment(clip->array,
+                                       GAL_STATISTICS_CLIP_OUTCOL_STD,
+                                       stype), twidth);
 
           /* Clean up. */
-          gal_data_free(sigmaclip);
+          gal_data_free(clip);
         }
       else
         {
@@ -160,9 +166,10 @@ sky(struct statisticsparams *p)
         printf("  - Kernel: %s (hdu: %s)\n", p->kernelname, p->khdu);
     }
 
+
   /* When checking steps, the input image is the first extension. */
   if(p->checksky)
-    gal_fits_img_write(p->input, p->checkskyname, NULL, PROGRAM_NAME);
+    gal_fits_img_write(p->input, p->checkskyname, NULL,  0);
 
 
   /* Convolve the image (if desired). */
@@ -170,10 +177,10 @@ sky(struct statisticsparams *p)
     {
       if(!cp->quiet) gettimeofday(&t1, NULL);
       p->convolved=gal_convolve_spatial(tl->tiles, p->kernel,
-                                        cp->numthreads, 1, tl->workoverch);
+                                        cp->numthreads, 1,
+                                        tl->workoverch, 0);
       if(p->checksky)
-        gal_fits_img_write(p->convolved, p->checkskyname, NULL,
-                           PROGRAM_NAME);
+        gal_fits_img_write(p->convolved, p->checkskyname, NULL, 0);
       if(!cp->quiet)
         gal_timing_report(&t1, "Input convolved with kernel.", 1);
     }
@@ -205,17 +212,24 @@ sky(struct statisticsparams *p)
   if(p->checksky)
     {
       gal_tile_full_values_write(p->sky_t, tl, !p->ignoreblankintiles,
-                                 p->checkskyname, NULL, PROGRAM_NAME);
+                                 p->checkskyname, NULL, 0);
       gal_tile_full_values_write(p->std_t, tl, !p->ignoreblankintiles,
-                                 p->checkskyname, NULL, PROGRAM_NAME);
+                                 p->checkskyname, NULL, 0);
     }
 
 
   /* Remove outliers if requested. */
-  gal_tileinternal_no_outlier_local(p->sky_t, p->std_t, NULL, &cp->tl,
-                                    cp->interpmetric, cp->interpnumngb,
-                                    cp->numthreads, p->outliersclip,
-                                    p->outliersigma, p->checkskyname);
+  if(p->outliernumngb)
+    gal_tileinternal_no_outlier_local(p->sky_t, p->std_t, NULL, &cp->tl,
+                                      cp->interpmetric, p->outliernumngb,
+                                      cp->numthreads, p->outliersclip,
+                                      p->outliersigma, p->checkskyname,
+                                      "--outliernumngb");
+
+  /* If the user only wants the sky level to this step, don't bother with
+     the rest (note that 'p->checksky' was activated in 'ui.c').  */
+  if(p->checkskynointerp)
+    exit(EXIT_SUCCESS);
 
 
   /* Interpolate the Sky and its standard deviation. */
@@ -235,9 +249,9 @@ sky(struct statisticsparams *p)
   if(p->checksky)
     {
       gal_tile_full_values_write(p->sky_t, tl, !p->ignoreblankintiles,
-                                 p->checkskyname, NULL, PROGRAM_NAME);
+                                 p->checkskyname, NULL, 0);
       gal_tile_full_values_write(p->std_t, tl, !p->ignoreblankintiles,
-                                 p->checkskyname, NULL, PROGRAM_NAME);
+                                 p->checkskyname, NULL, 0);
     }
 
 
@@ -259,9 +273,9 @@ sky(struct statisticsparams *p)
       if(p->checksky)
         {
           gal_tile_full_values_write(p->sky_t, tl, !p->ignoreblankintiles,
-                                     p->checkskyname, NULL, PROGRAM_NAME);
+                                     p->checkskyname, NULL, 0);
           gal_tile_full_values_write(p->std_t, tl, !p->ignoreblankintiles,
-                                     p->checkskyname, NULL, PROGRAM_NAME);
+                                     p->checkskyname, NULL, 0);
           if(!cp->quiet)
             printf("  - Check image written to '%s'.\n", p->checkskyname);
         }
@@ -281,14 +295,13 @@ sky(struct statisticsparams *p)
   p->std_t->name="SKY_STD";
   p->cp.keepinputdir=keepinputdir;
   gal_tile_full_values_write(p->sky_t, tl, !p->ignoreblankintiles, outname,
-                             NULL, PROGRAM_NAME);
+                             NULL, 0);
   gal_tile_full_values_write(p->std_t, tl, !p->ignoreblankintiles, outname,
-                             NULL, PROGRAM_NAME);
+                             NULL, 0);
   p->sky_t->name = p->std_t->name = NULL;
-  gal_fits_key_write_filename("input", p->inputname, &p->cp.okeys, 1,
+  gal_fits_key_write_filename("input", p->inputname, &p->cp.ckeys, 1,
                               p->cp.quiet);
-  gal_fits_key_write_config(&p->cp.okeys, "Statistics configuration",
-                            "STATISTICS-CONFIG", outname, "0");
+  gal_fits_key_write(p->cp.ckeys, outname, "0", "NONE", 1, 0);
   if(!cp->quiet)
     printf("  - Sky and its STD written to '%s'.\n", outname);
 
