@@ -30,8 +30,6 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <stdlib.h>
 
-#include <gsl/gsl_fit.h>
-
 #include <gnuastro/fit.h>
 #include <gnuastro/wcs.h>
 #include <gnuastro/fits.h>
@@ -122,10 +120,10 @@ statistics_print_one_row(struct statisticsparams *p)
   int mustfree;
   char *toprint;
   double arg, *d;
-  uint8_t clipflag;
-  gal_list_i32_t *tmp;
   gal_data_t *medmad=NULL;
   size_t dsize=1, counter;
+  uint8_t clipflag, hasmad;
+  gal_list_i32_t *tmp, *ttmp;
   gal_data_t *sclip=NULL, *mclip=NULL;
   gal_data_t *sum=NULL, *meanstd=NULL, *modearr=NULL;
   gal_data_t *tmpv, *out=NULL, *num=NULL, *min=NULL, *max=NULL;
@@ -155,7 +153,18 @@ statistics_print_one_row(struct statisticsparams *p)
         break;
       case UI_KEY_MAD:
       case UI_KEY_MEDIAN:
-        medmad = medmad ? medmad : gal_statistics_median_mad(p->input, 0);
+        if(medmad==NULL)
+          {
+            /* If MAD is requested, the median is a free byproduct. But if
+               MAD is not requested, we don't want to waste the user's time
+               for calculating it. */
+            hasmad=0;
+            for(ttmp=p->singlevalue; ttmp!=NULL; ttmp=ttmp->next)
+              if(ttmp->v==UI_KEY_MAD) hasmad=1;
+            medmad = ( hasmad
+                       ? gal_statistics_median_mad(p->input, 0)
+                       : gal_statistics_median(p->input, 0) );
+          }
         break;
       case UI_KEY_MODE:
       case UI_KEY_MODEQUANT:
@@ -201,6 +210,7 @@ statistics_print_one_row(struct statisticsparams *p)
       /* These will be calculated as printed. */
       case UI_KEY_QUANTILE:
       case UI_KEY_QUANTFUNC:
+      case UI_KEY_CONCENTRATION:
         break;
 
       /* The option isn't recognized. */
@@ -283,7 +293,13 @@ statistics_print_one_row(struct statisticsparams *p)
                                  GAL_STATISTICS_CLIP_OUTCOL_NUMBER_USED);
           mustfree=1; break;
 
-        /* Not previously calculated. */
+        /* Not previously calculated; because they can have multiple input
+           arguments. */
+        case UI_KEY_CONCENTRATION:
+          arg=statistics_read_check_args(p);
+          out=gal_statistics_concentration(p->sorted, arg, 1);
+          break;
+
         case UI_KEY_QUANTILE:
           mustfree=1;
           arg = statistics_read_check_args(p);
@@ -310,9 +326,9 @@ statistics_print_one_row(struct statisticsparams *p)
 
         /* The option isn't recognized. */
         default:
-          error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s so we "
-                "can address the problem. Operation code %d not recognized",
-                __func__, PACKAGE_BUGREPORT, tmp->v);
+          error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s so "
+                "we can address the problem. Operation code %d not "
+                "recognized", __func__, PACKAGE_BUGREPORT, tmp->v);
         }
 
       /* Print the number. Note that we don't want any extra white space
@@ -390,9 +406,80 @@ statistics_interpolate_and_write(struct statisticsparams *p,
   /* Write the values. */
   gal_tile_full_values_write(values, &cp->tl, !p->ignoreblankintiles,
                              output, NULL, 0);
-  gal_fits_key_write_filename("input", p->inputname, &p->cp.ckeys, 1,
-                              p->cp.quiet);
-  gal_fits_key_write(p->cp.ckeys, output, "0", "NONE", 1, 0);
+}
+
+
+
+
+
+static gal_data_t *
+statistics_on_tile_clip(struct statisticsparams *p, gal_data_t *tile,
+                        int operator)
+{
+  int s1m0=0;
+  uint8_t cflag;
+  size_t ind, one=1;
+  gal_data_t *clip, *out;
+
+  /* Pre-operation settings. */
+  switch(operator)
+    {
+    /* MAD-clipping */
+    case UI_KEY_MADCLIPMAD:
+      s1m0=0; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_MAD; break;
+    case UI_KEY_MADCLIPNUMBER:
+      s1m0=0; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_NUMBER_USED; break;
+    case UI_KEY_MADCLIPMEDIAN:
+      s1m0=0; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_MEDIAN; break;
+    case UI_KEY_MADCLIPSTD:
+      s1m0=0; cflag=GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_STD;
+      ind=GAL_STATISTICS_CLIP_OUTCOL_STD; break;
+    case UI_KEY_MADCLIPMEAN:
+      s1m0=0; cflag=GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_MEAN;
+      ind=GAL_STATISTICS_CLIP_OUTCOL_MEAN; break;
+
+    /* Sigma-clipping */
+    case UI_KEY_SIGCLIPSTD:
+      s1m0=1; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_STD; break;
+    case UI_KEY_SIGCLIPNUMBER:
+      s1m0=1; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_NUMBER_USED; break;
+    case UI_KEY_SIGCLIPMEDIAN:
+      s1m0=1; cflag=0; ind=GAL_STATISTICS_CLIP_OUTCOL_MEDIAN; break;
+    case UI_KEY_SIGCLIPMAD:
+      s1m0=0; cflag=GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_MAD;
+      ind=GAL_STATISTICS_CLIP_OUTCOL_MAD; break;
+    case UI_KEY_SIGCLIPMEAN:
+      s1m0=0; cflag=GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_MEAN;
+      ind=GAL_STATISTICS_CLIP_OUTCOL_MEAN; break;
+
+    /* None of the above (a bug!). */
+    default:
+      error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to fix "
+            "the problem. The operator identifier %d should not have "
+            "been given to this function", __func__, PACKAGE_BUGREPORT,
+            operator);
+    }
+
+  /* Do the clipping, and a small sanity check on the type of the output
+     (in case it changes in the future). */
+  clip = ( s1m0
+           ? gal_statistics_clip_mad(tile, p->mclipparams[0],
+                                     p->mclipparams[1], cflag,
+                                     0, 1)
+           : gal_statistics_clip_sigma(tile, p->sclipparams[0],
+                                       p->sclipparams[1], cflag,
+                                       0, 1) );
+
+  /* Write the desired value into the output. */
+  out=gal_data_alloc(NULL, clip->type, 1, &one, NULL, 0, -1, 1,
+                     NULL, NULL, NULL);
+  memcpy( out->array,
+          gal_pointer_increment(clip->array, ind, clip->type),
+          gal_type_sizeof(clip->type) );
+
+  /* Return the clipped dataset */
+  gal_data_free(clip);
+  return out;
 }
 
 
@@ -407,13 +494,23 @@ statistics_on_tile(struct statisticsparams *p)
   gal_data_t *tile, *values;
   size_t tind, dsize=1, mind=-1;
   uint8_t type=GAL_TYPE_INVALID;
+  uint8_t keepinputdir=p->cp.keepinputdir;
   gal_data_t *tmp=NULL, *tmpv=NULL, *ttmp;
   struct gal_options_common_params *cp=&p->cp;
   struct gal_tile_two_layer_params *tl=&p->cp.tl;
-  char *output=gal_checkset_automatic_output(cp, cp->output
-                                             ? cp->output
-                                             : p->inputname,
-                                             "_ontile.fits");
+  char *output;
+
+  /* Save the Sky and its standard deviation. We want the output to have a
+     '_sky.fits' suffix. So we'll temporarily re-set 'p->cp.keepinputdir'
+     if the user asked for a specific name. Note that we copied the actual
+     value in the 'keepinputdir' above (in the definition). */
+  p->cp.keepinputdir = p->cp.output ? 1 : keepinputdir;
+  output=gal_checkset_automatic_output(cp,
+                                       ( cp->output
+                                         ? cp->output
+                                         : p->inputname ),
+                                       "_ontile.fits");
+  p->cp.keepinputdir=keepinputdir;
 
   /* Do the operation on each tile. */
   for(operation=p->singlevalue; operation!=NULL; operation=operation->next)
@@ -424,22 +521,34 @@ statistics_on_tile(struct statisticsparams *p)
         case UI_KEY_NUMBER:
           type=GAL_TYPE_INT32; break;
 
+        case UI_KEY_MODE:
+        case UI_KEY_MEDIAN:
         case UI_KEY_MINIMUM:
         case UI_KEY_MAXIMUM:
-        case UI_KEY_MEDIAN:
-        case UI_KEY_MODE:
         case UI_KEY_QUANTFUNC:
           type=p->input->type; break;
 
         case UI_KEY_SUM:
-        case UI_KEY_MEAN:
         case UI_KEY_STD:
+        case UI_KEY_MEAN:
+        case UI_KEY_MODESYM:
         case UI_KEY_QUANTILE:
         case UI_KEY_MODEQUANT:
-        case UI_KEY_MODESYM:
         case UI_KEY_MODESYMVALUE:
           type=GAL_TYPE_FLOAT64; break;
 
+        case UI_KEY_MADCLIPSTD:
+        case UI_KEY_SIGCLIPSTD:
+        case UI_KEY_MADCLIPMAD:
+        case UI_KEY_SIGCLIPMAD:
+        case UI_KEY_MADCLIPMEAN:
+        case UI_KEY_SIGCLIPMEAN:
+        case UI_KEY_MADCLIPNUMBER:
+        case UI_KEY_SIGCLIPNUMBER:
+        case UI_KEY_MADCLIPMEDIAN:
+        case UI_KEY_SIGCLIPMEDIAN:
+          type=GAL_TYPE_FLOAT32; break;
+
         default:
           error(EXIT_FAILURE, 0, "%s: a bug! %d is not a recognized "
                 "operation code", __func__, operation->v);
@@ -516,10 +625,24 @@ statistics_on_tile(struct statisticsparams *p)
               tmp=ttmp;
               break;
 
+            case UI_KEY_MADCLIPSTD:
+            case UI_KEY_SIGCLIPSTD:
+            case UI_KEY_MADCLIPMAD:
+            case UI_KEY_SIGCLIPMAD:
+            case UI_KEY_MADCLIPMEAN:
+            case UI_KEY_SIGCLIPMEAN:
+            case UI_KEY_MADCLIPNUMBER:
+            case UI_KEY_SIGCLIPNUMBER:
+            case UI_KEY_MADCLIPMEDIAN:
+            case UI_KEY_SIGCLIPMEDIAN:
+              tmp=statistics_on_tile_clip(p, tile, operation->v);
+              break;
+
             default:
-              error(EXIT_FAILURE, 0, "%s: a bug! please contact us at %s to "
-                    "fix the problem. The operation code %d is not "
-                    "recognized", __func__, PACKAGE_BUGREPORT, operation->v);
+              error(EXIT_FAILURE, 0, "%s: a bug! please contact us at %s "
+                    "to fix the problem. The operation code %d is not "
+                    "recognized", __func__, PACKAGE_BUGREPORT,
+                    operation->v);
             }
 
           /* Put the output value into the 'values' array and clean up. */
@@ -538,6 +661,11 @@ statistics_on_tile(struct statisticsparams *p)
       if(operation->v==UI_KEY_QUANTFUNC) gal_data_free(tmpv);
     }
 
+  /* Write the keywords in the 0-th extension. */
+  gal_fits_key_write_filename("input", p->inputname, &p->cp.ckeys, 1,
+                              p->cp.quiet);
+  gal_fits_key_write(p->cp.ckeys, output, "0", "NONE", 1, 0);
+
   /* Clean up. */
   free(output);
 }
@@ -1151,17 +1279,21 @@ print_basics(struct statisticsparams *p)
      range shown in the basic information section applies to that, not the
      range of the histogram. In that case, we want to print the histogram
      information. */
-  printf("-------");
-  range=set_bin_range_params(p, 1);
-  p->asciiheight = p->asciiheight ? p->asciiheight : 10;
-  p->numasciibins = p->numasciibins ? p->numasciibins : 70;
-  bins=gal_statistics_regular_bins(p->input, range, p->numasciibins, NAN);
-  hist=gal_statistics_histogram(p->input, bins, 0, 0);
-  printf("\nHistogram:\n");
-  print_ascii_plot(p, hist, bins, 1, 0);
-  gal_data_free(bins);
-  gal_data_free(hist);
-  gal_data_free(range);
+  printf("-------\nHistogram:\n");
+  if(p->input->size)
+    {
+      range=set_bin_range_params(p, 1);
+      p->asciiheight = p->asciiheight ? p->asciiheight : 10;
+      p->numasciibins = p->numasciibins ? p->numasciibins : 70;
+      bins=gal_statistics_regular_bins(p->input, range, p->numasciibins,
+                                       NAN);
+      hist=gal_statistics_histogram(p->input, bins, 0, 0);
+      print_ascii_plot(p, hist, bins, 1, 0);
+      gal_data_free(bins);
+      gal_data_free(hist);
+      gal_data_free(range);
+    }
+  else printf("  No data");
 }
 
 
@@ -1229,9 +1361,11 @@ print_clip(struct statisticsparams *p, int sig1_mad0)
      call other operators also. */
   result = ( sig1_mad0
              ? gal_statistics_clip_sigma(p->sorted, clipparams[0],
-                                         clipparams[1], flags, 0, p->cp.quiet)
+                                         clipparams[1], flags, 0,
+                                         p->cp.quiet)
              : gal_statistics_clip_mad(p->sorted, clipparams[0],
-                                       clipparams[1], flags, 0, p->cp.quiet) );
+                                       clipparams[1], flags, 0,
+                                       p->cp.quiet) );
   a=result->array;
 
   /* Finish the introduction. */
