@@ -218,19 +218,17 @@ ui_add_to_single_value(struct argp_option *option, char *arg,
                       char *filename, size_t lineno, void *params)
 {
   size_t i;
+  char *str;
   double *d;
   gal_data_t *inputs=NULL;
   struct statisticsparams *p=(struct statisticsparams *)params;
 
   /* In case of printing the option values. */
   if(lineno==-1)
-    error(EXIT_FAILURE, 0, "currently the options to be printed in one "
-          "row (like '--number', '--mean', and etc) do not support "
-          "printing with the '--printparams' ('-P'), or writing into "
-          "configuration files due to lack of time when implementing "
-          "these features. You can put them into configuration files "
-          "manually. Please get in touch with us at '%s', so we can "
-          "implement it", PACKAGE_BUGREPORT);
+    {
+      gal_checkset_allocate_copy("1", &str);
+      return str;
+    }
 
   /* Some of these options take values and some don't. */
   if(option->type==GAL_OPTIONS_NO_ARG_TYPE)
@@ -266,6 +264,19 @@ ui_add_to_single_value(struct argp_option *option, char *arg,
       d=inputs->array;
       switch(option->key)
         {
+        case UI_KEY_CONCENTRATION:
+          for(i=0;i<inputs->size;++i)
+            {
+              if(d[i]>0.5f || d[i]<=0.0f)
+                error(EXIT_FAILURE, 0, "%g (value given to "
+                      "'--concentration': quantile range around median) "
+                      "should be larger than 0 and smaller than 0.5",
+                      d[i]);
+              gal_list_f64_add(&p->tp_args, d[i]);
+              gal_list_i32_add(&p->singlevalue, option->key);
+            }
+          break;
+
         case UI_KEY_QUANTILE:
         case UI_KEY_QUANTFUNC:
           /* For the quantile and the quantile function, its possible to
@@ -393,6 +404,7 @@ ui_check_only_options(struct statisticsparams *p)
   gal_list_i32_t *tmp;
   struct gal_tile_two_layer_params *tl=&p->cp.tl;
 
+
   /* Check if the format of the output table is valid, given the type of
      the output. */
   gal_tableintern_check_fits_format(p->cp.output, p->cp.tableformat);
@@ -404,6 +416,7 @@ ui_check_only_options(struct statisticsparams *p)
           "(for example '--median') must be requested with the '--ontile' "
           "option: there is no value to put in each tile");
 
+
   /* Tessellation related options. */
   if( p->ontile || p->sky )
     {
@@ -825,6 +838,7 @@ ui_make_sorted_if_necessary(struct statisticsparams *p)
       case UI_KEY_SIGCLIPNUMBER:
       case UI_KEY_MADCLIPMEDIAN:
       case UI_KEY_SIGCLIPMEDIAN:
+      case UI_KEY_CONCENTRATION:
         is_necessary=1;
         break;
       }
@@ -1233,17 +1247,15 @@ ui_preparations(struct statisticsparams *p)
       if(p->input->next) gal_blank_remove_rows(p->input, NULL, 0);
       else               gal_blank_remove(p->input);
 
-      /* Make sure there actually are any (non-blank) elements left. */
-      if(p->input->size==0)
-        error(EXIT_FAILURE, 0, "%s: all elements are blank",
+      /* If all elements are blank and the user has not asked for
+         Statistics to be quiet, then let the user know. */
+      if(!p->cp.quiet && p->input->size==0)
+        error(EXIT_SUCCESS, 0, "WARNING: %s: no usable (non-blank) data. "
+              "If there is data in the input, maybe the '--greaterequal' "
+              "or '--lessthan' options need to be adjusted. To remove "
+              "this warning, use the '--quiet' (or '-q') option",
               gal_fits_name_save_as_string(p->inputname, cp->hdu));
 
-      /* Make sure there is data remaining: */
-      if(p->input->size==0)
-        error(EXIT_FAILURE, 0, "%s: no data, maybe the '--greaterequal' "
-              "or '--lessthan' options need to be adjusted",
-              gal_fits_name_save_as_string(p->inputname, cp->hdu) );
-
       /* Make the sorted array if necessary. */
       ui_make_sorted_if_necessary(p);
 
