@@ -5,7 +5,7 @@ Statistics is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -81,6 +81,8 @@ enum option_keys_enum
   UI_KEY_MINIMUM,
   UI_KEY_MAXIMUM,
   UI_KEY_SUM,
+  UI_KEY_MAD,
+  UI_KEY_MADCLIP,
   UI_KEY_MODEQUANT,
   UI_KEY_MODESYM,
   UI_KEY_MODESYMVALUE,
@@ -104,12 +106,20 @@ enum option_keys_enum
   UI_KEY_OUTLIERSCLIP,
   UI_KEY_SMOOTHWIDTH,
   UI_KEY_CHECKSKY,
+  UI_KEY_CHECKSKYNOINTERP,
   UI_KEY_IGNOREBLANKINTILES,
   UI_KEY_SCLIPPARAMS,
+  UI_KEY_MCLIPPARAMS,
   UI_KEY_SIGCLIPNUMBER,
   UI_KEY_SIGCLIPMEDIAN,
   UI_KEY_SIGCLIPMEAN,
   UI_KEY_SIGCLIPSTD,
+  UI_KEY_SIGCLIPMAD,
+  UI_KEY_MADCLIPNUMBER,
+  UI_KEY_MADCLIPMEDIAN,
+  UI_KEY_MADCLIPMEAN,
+  UI_KEY_MADCLIPSTD,
+  UI_KEY_MADCLIPMAD,
   UI_KEY_GREATEREQUAL2,
   UI_KEY_LESSTHAN2,
   UI_KEY_ONEBINSTART2,
@@ -118,6 +128,7 @@ enum option_keys_enum
   UI_KEY_FITESTIMATEHDU,
   UI_KEY_FITESTIMATECOL,
   UI_KEY_FITROBUST,
+  UI_KEY_CONCENTRATION,
 };
 
 
