@@ -5,7 +5,7 @@ Table is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -147,7 +147,7 @@ struct argp_option program_options[] =
       UI_KEY_INFORMATION,
       0,
       0,
-      "Only print table and column information.",
+      "Only print input table's information.",
       GAL_OPTIONS_GROUP_OUTPUT,
       &p->information,
       GAL_OPTIONS_NO_ARG_TYPE,
@@ -155,6 +155,32 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+    {
+      "info-num-rows",
+      UI_KEY_INFONUMROWS,
+      0,
+      0,
+      "Only print input table's number of rows.",
+      GAL_OPTIONS_GROUP_OUTPUT,
+      &p->infonumrows,
+      GAL_OPTIONS_NO_ARG_TYPE,
+      GAL_OPTIONS_RANGE_0_OR_1,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "info-num-cols",
+      UI_KEY_INFONUMCOLS,
+      0,
+      0,
+      "Only print input table's number of columns.",
+      GAL_OPTIONS_GROUP_OUTPUT,
+      &p->infonumcols,
+      GAL_OPTIONS_NO_ARG_TYPE,
+      GAL_OPTIONS_RANGE_0_OR_1,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
     {
       "colinfoinstdout",
       UI_KEY_COLINFOINSTDOUT,
