@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2021, Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -46,6 +46,41 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 /*********************************************************************/
 /*****************      Erosion and dilation      ********************/
 /*********************************************************************/
+static void
+binary_erode_dilate_1d(gal_data_t *input, int dilate0_erode1)
+{
+  size_t i, nr=input->dsize[0];
+  uint8_t f, b, *pt, *fpt, *byt=input->array;
+
+  /* Do a sanity check: */
+  if(dilate0_erode1!=1 && dilate0_erode1!=0)
+    error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s so we can "
+          "fix this problem. The value to 'dilate0_erode1' is %u while it "
+          "should be 0 or 1", __func__, PACKAGE_BUGREPORT, dilate0_erode1);
+
+  /* Set the foreground and background values. */
+  if(dilate0_erode1==0) {f=1; b=0;}
+  else                  {f=0; b=1;}
+
+  /* Check the two extremes. */
+  if(byt[0]==b && byt[1]==f ) byt[0]=GAL_BINARY_TMP_VALUE;
+  if(nr>2)
+    if(byt[nr-1]==b && byt[nr-2]==f) byt[nr-1] = GAL_BINARY_TMP_VALUE;
+
+  /* Go over the full array. */
+  for(i=1;i<nr;++i)
+    if( byt[i]==b && ( byt[i-1]==f || byt[i+1]==f ) )
+      byt[i]=GAL_BINARY_TMP_VALUE;
+
+  /* Set all the changed pixels to the proper values: */
+  fpt=(pt=byt)+nr;
+  do *pt = *pt==GAL_BINARY_TMP_VALUE ? f : *pt; while(++pt<fpt);
+}
+
+
+
+
+
 static void
 binary_erode_dilate_2d_4con(gal_data_t *input, int dilate0_erode1)
 {
@@ -290,6 +325,10 @@ binary_erode_dilate(gal_data_t *input, size_t num, int connectivity,
   /* Go over every element and do the erosion. */
   switch(binary->ndim)
     {
+    case 1:
+      binary_erode_dilate_1d(binary, d0e1);
+      break;
+
     case 2:
       for(counter=0;counter<num;++counter)
         switch(connectivity)
@@ -380,6 +419,69 @@ gal_binary_open(gal_data_t *input, size_t num, int connectivity,
 
 
 
+/*********************************************************************/
+/*****************            Neighbors           ********************/
+/*********************************************************************/
+/* This is a general erosion and dilation function. It is less efficient
+   than the more specialized cases above. */
+gal_data_t *
+gal_binary_number_neighbors(gal_data_t *input, int connectivity, int inplace)
+{
+  gal_data_t *out;
+  uint8_t n, *narr, *byt=input->array;
+  size_t i, *dinc=gal_dimension_increment(input->ndim, input->dsize);
+
+  /* Currently this only works on blocks. */
+  if(input->block)
+    error(EXIT_FAILURE, 0, "%s: currently only works on a fully "
+          "allocated block of memory, but the input is a tile (its 'block' "
+          "element is not NULL)", __func__);
+
+  /* The input must have a uint8 datatype. */
+  if(input->type!=GAL_TYPE_UINT8)
+    error(EXIT_FAILURE, 0, "%s: input must have an unsigned 8-bit "
+          "datatype but has a type of %s\n", __func__,
+          gal_type_name(input->type, 1));
+
+  /* Allocate the output dataset. */
+  out = ( inplace
+          ? input
+          : gal_data_alloc(NULL, GAL_TYPE_UINT8, input->ndim, input->dsize,
+                           input->wcs, 1, input->minmapsize, input->quietmmap,
+                           NULL, NULL, NULL) );
+  narr=out->array;
+
+  /* Go over the neighbors of each pixel. */
+  for(i=0;i<input->size;++i)
+    if(byt[i] && byt[i]!=GAL_BLANK_UINT8)
+      {
+        n=0;
+        GAL_DIMENSION_NEIGHBOR_OP(i, input->ndim, input->dsize, connectivity,
+                                  dinc, { n += byt[nind]>0; });
+        narr[i]=n;
+      }
+
+  /* Return the output dataset. */
+  return out;
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 /*********************************************************************/
 /*****************      Connected components      ********************/
 /*********************************************************************/
@@ -435,8 +537,8 @@ gal_binary_connected_components(gal_data_t *binary, gal_data_t **out,
      array, then give them the blank labeled array. Note that since
      their value will not be 0, they will also not be labeled. */
   l=lab->array;
-  bf=(b=binary->array)+binary->size; /* Library must have no side effect,   */
-  if( gal_blank_present(binary, 0) ) /* So blank flag should not be changed.*/
+  bf=(b=binary->array)+binary->size; /* Library must have no side effect:*/
+  if( gal_blank_present(binary, 0) ) /* blank flag should not be changed.*/
     do *l++ = *b==GAL_BLANK_UINT8 ? GAL_BLANK_INT32 : 0; while(++b<bf);
 
 
@@ -446,6 +548,7 @@ gal_binary_connected_components(gal_data_t *binary, gal_data_t **out,
   l=lab->array;
   b=binary->array;
   for(i=0;i<binary->size;++i)
+
     /* Check if this pixel is already labeled. */
     if( b[i] && l[i]==0 )
       {
@@ -548,7 +651,8 @@ gal_binary_connected_indexs(gal_data_t *binary, int connectivity)
 	/* Parsing has finished, put all the indexs into an array. */
 	onelabarr=gal_list_sizet_to_array(onelab, 1, &onelabnum);
 	gal_list_data_add_alloc(&lines, onelabarr, GAL_TYPE_SIZE_T, 1,
-				&onelabnum, NULL, 0, -1, 1, NULL, NULL, NULL);
+				&onelabnum, NULL, 0, -1, 1, NULL, NULL,
+                                NULL);
 
 	/* Clean up. */
 	gal_list_sizet_free(onelab);
@@ -949,18 +1053,16 @@ gal_binary_holes_fill(gal_data_t *input, int connectivity, size_t maxsize)
           "It has to be between 1 and the number of input's dimensions "
           "(%zu)", __func__, connectivity, input->ndim);
 
-
   /* Make the inverse image. */
   inv=binary_make_padded_inverse(input, &tile);
 
-
   /* Label the holes */
   numholes=gal_binary_connected_components(inv, &holelabs, connectivity);
 
-
-  /* Any pixel with a label larger than 1 is a hole in the input image and
-     we should invert the respective pixel. To do it, we'll use the tile
-     that was defined before, just change its block and array.*/
+  /* Any pixel with a label that is not touching the edges is a hole in the
+     input image and we should invert the respective pixel. To do it, we'll
+     use the tile that was defined before, just change its block and
+     array. */
   in=input->array;
   tile->array=gal_tile_block_relative_to_other(tile, holelabs);
   tile->block=holelabs; /* has to be after correcting 'tile->array'. */
@@ -988,9 +1090,16 @@ gal_binary_holes_fill(gal_data_t *input, int connectivity, size_t maxsize)
   /* The type of the tile is already known (it is 'int32_t') and we have no
      output, so we'll just put 'int' as a place-holder. In this way we can
      avoid the switch statement of GAL_TILE_PARSE_OPERATE, and directly use
-     the workhorse macro 'GAL_TILE_PO_OISET'. */
+     the workhorse macro 'GAL_TILE_PO_OISET'.
+
+     For inputs of any dimensionality, the label=1 is not a hole. For 1D
+     data, the last label is also not a hole (because in 1D the start and
+     end of the array don't touch).
+  */
   GAL_TILE_PO_OISET(int32_t, int, tile, NULL, 0, 0, {
-      *in = *i>1 && *i!=GAL_BLANK_INT32 ? 1 : *in;
+      *in = ( *i==GAL_BLANK_INT32
+              || *i==1
+              || (input->ndim==1 && *i==numholes) ) ? *in : 1;
       ++in;
     });
 
