@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -167,7 +167,7 @@ eps_convert_to_bitstream(gal_data_t *in, size_t *numbytes, uint8_t bitone)
     {
       /* Allocate the array. Note that we currently don't have an
          allocation system for bits, so we'll allocate space in bytes, then
-         convert  */
+         convert the type to 'GAL_TYPE_BIT'. */
       gal_list_data_add_alloc(&out, NULL, GAL_TYPE_UINT8, 1, numbytes,
                               NULL, 0, -1, 1, NULL, NULL, NULL);
       out->type=GAL_TYPE_BIT;
@@ -876,8 +876,8 @@ eps_mark_in_img_fl_pixel(float x, float y, float s1, float s2,
   switch(shape)
     {
     case GAL_EPS_MARK_SHAPE_LINE:
-      width[0]=s1; width[1]=0.1; break; /* We will add line-width later, */
-                                        /* And width[1] shouldn't be 0.  */
+      width[0]=s1; width[1]=0; break;   /* EPS line-width will be added */
+                                        /* later, this is the box size. */
     case GAL_EPS_MARK_SHAPE_PLUS:
     case GAL_EPS_MARK_SHAPE_SQUARE:
       width[0]=width[1]=s1; break;
