@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017-2023 Free Software Foundation, Inc.
+Copyright (C) 2017-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -131,6 +131,12 @@ gal_blank_flag(gal_data_t *data);
 gal_data_t *
 gal_blank_flag_not(gal_data_t *input);
 
+size_t *
+gal_blank_not_minmax_coords(gal_data_t *input);
+
+gal_data_t *
+gal_blank_trim(gal_data_t *input, int inplace);
+
 void
 gal_blank_flag_apply(gal_data_t *input, gal_data_t *flag);
 
