@@ -199,6 +199,16 @@ gal_statistics_cfp(gal_data_t *data, gal_data_t *bins, int normalize);
 
 
 
+/****************************************************************
+ *****************     Distribution shape    ********************
+ ****************************************************************/
+gal_data_t *
+gal_statistics_concentration(gal_data_t *input, double width,
+                             int inplace);
+
+
+
+
 /****************************************************************
  *****************         Outliers          ********************
  ****************************************************************/
