@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017-2023 Free Software Foundation, Inc.
+Copyright (C) 2017-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -153,7 +153,7 @@ void
 gal_tile_full_values_write(gal_data_t *tilevalues,
                            struct gal_tile_two_layer_params *tl,
                            int withblank, char *filename,
-                           gal_fits_list_key_t *keys, char *program_string);
+                           gal_fits_list_key_t *keys, int freekeys);
 
 gal_data_t *
 gal_tile_full_values_smooth(gal_data_t *tilevalues,
