@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2022 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -32,6 +32,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/eps.h>
 #include <gnuastro/pdf.h>
 #include <gnuastro/jpeg.h>
+#include <gnuastro/pointer.h>
 
 #include <gnuastro-internal/checkset.h>
 
@@ -103,8 +104,10 @@ gal_pdf_write(gal_data_t *in, char *filename, float widthincm,
               uint32_t borderwidth, uint8_t bordercolor,
               int dontoptimize, gal_data_t *marks)
 {
+  int execstat=0;
   size_t w_h_in_pt[2];
-  char *command, *device;
+  gal_list_str_t *command=NULL;
+  char *device, *devwp, *devhp, *devopt;
   char *epsname=gal_checkset_malloc_cat(filename, ".ps");
 
   /* Write the EPS file. */
@@ -114,33 +117,52 @@ gal_pdf_write(gal_data_t *in, char *filename, float widthincm,
   /* Get the size of the image in 'pt' units. */
   gal_eps_to_pt(widthincm, in->dsize, w_h_in_pt);
 
-  /* Set the device from the file name */
+  /* Set the device from the file name. */
   if(gal_jpeg_name_is_jpeg(filename)) device="jpeg";
   else                                device="pdfwrite";
 
-  /* Write the ghostscript command to compile the EPS file to PDF. */
-  if( asprintf(&command, "gs -q -o %s -sDEVICE=%s "
-               "-dDEVICEWIDTHPOINTS=%zu -dDEVICEHEIGHTPOINTS=%zu "
-               "-dPDFFitPage %s", filename, device,
-               w_h_in_pt[0]+2*borderwidth, w_h_in_pt[1]+2*borderwidth,
-               epsname)<0 )
+  /* Build the necessary strings. */
+  if( asprintf(&devwp, "-dDEVICEWIDTHPOINTS=%zu",
+               w_h_in_pt[0]+2*borderwidth)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation error", __func__);
+  if( asprintf(&devhp, "-dDEVICEHEIGHTPOINTS=%zu",
+               w_h_in_pt[1]+2*borderwidth)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation error", __func__);
+  if( asprintf(&devopt, "-sDEVICE=%s", device)<0 )
     error(EXIT_FAILURE, 0, "%s: asprintf allocation error", __func__);
 
-  /* Run Ghostscript. */
-  if(system(command))
-    error(EXIT_FAILURE, 0, "the Ghostscript command (printed after "
-          "this message) to convert the EPS file to PDF was not "
-          "successful! The EPS file ('%s') is left if you want to "
-          "convert it through any other means (for example the "
-          "'epspdf' program). The Ghostscript command was: %s",
-          epsname, command);
+  /* Run Ghostscript (if the command changes, also change the command in
+     the error message).  */
+  gal_list_str_add(&command, PATH_GHOSTSCRIPT, 0);
+  gal_list_str_add(&command, "-q", 0);
+  gal_list_str_add(&command, "-o", 0);
+  gal_list_str_add(&command, filename, 0);
+  gal_list_str_add(&command, devopt, 0);
+  gal_list_str_add(&command, devwp, 0);
+  gal_list_str_add(&command, devhp, 0);
+  gal_list_str_add(&command, "-dPDFFitPage", 0);
+  gal_list_str_add(&command, epsname, 0);
+  gal_list_str_reverse(&command);
+  execstat=gal_checkset_exec(PATH_GHOSTSCRIPT, command);
+  if(execstat)
+    error(EXIT_FAILURE, 0, "the Ghostscript command (printed at the "
+          "end of this message) to convert/compile the EPS file (made "
+          "by Gnuastro) to PDF was not successful (Ghostscript returned "
+          "with status %d; its error message is shown above)! The EPS "
+          "file ('%s') is left if you want to convert it through any "
+          "other means (for example the 'epspdf' program). The "
+          "Ghostscript command was: %s", execstat, epsname,
+          gal_list_str_cat(command, ' '));
 
   /* Delete the EPS file. */
   errno=0;
   if(unlink(epsname))
     error(EXIT_FAILURE, errno, "%s", epsname);
 
-  /* Clean up. */
-  free(command);
+  /* Clean up the command list and delete the EPS file. */
+  free(devhp);
+  free(devwp);
+  free(devopt);
   free(epsname);
+  gal_list_str_free(command, 0);
 }
