@@ -7,7 +7,7 @@ Original author:
 Contributing author(s):
      Sachin Kumar Singh <sachinkumarsingh092@gmail.com>
      Pedram Ashofteh-Ardakani <pedramardakani@pm.me>
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -47,14 +47,18 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 /* The cross product of two points from the center. */
 #define GAL_POLYGON_CROSS_PRODUCT(A, B) ( (A)[0]*(B)[1] - (B)[0]*(A)[1] )
 
-
-
+/* For spherical coordinates: the RA is only in units of degrees on the
+   equator: as we got to higher or lower declinations, any difference in RA
+   should be multiplied by the cos(DEC).*/
+#define GAL_POLYGON_CROSS_PRODUCT_SKY(A, B) \
+  (   (A)[0]*(B)[1]*cos((A)[1]*M_PI/180) \
+    - (B)[0]*(A)[1]*cos((B)[1]*M_PI/180)  )
 
 /* Find the cross product (2*area) between three points. Each point is
    assumed to be a pointer that has atleast two values within it. */
-#define GAL_POLYGON_TRI_CROSS_PRODUCT(A, B, C)    \
-  ( ( (B)[0]-(A)[0] ) * ( (C)[1]-(A)[1] ) -       \
-    ( (C)[0]-(A)[0] ) * ( (B)[1]-(A)[1] ) )       \
+#define GAL_POLYGON_TRI_CROSS_PRODUCT(A, B, C) \
+  (   ( (B)[0]-(A)[0] ) * ( (C)[1]-(A)[1] )    \
+    - ( (C)[0]-(A)[0] ) * ( (B)[1]-(A)[1] ) )
 
 
 
@@ -121,7 +125,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 /**************       Basic operations        ******************/
 /***************************************************************/
 
-/* Sort the pixels in anti clock-wise order.*/
+/* Sort the pixels in anti clock-wise order. */
 void
 gal_polygon_vertices_sort_convex(double *in, size_t n, size_t *ordinds)
 {
@@ -130,11 +134,12 @@ gal_polygon_vertices_sort_convex(double *in, size_t n, size_t *ordinds)
     tindexs[GAL_POLYGON_MAX_CORNERS];
 
   if(n>GAL_POLYGON_MAX_CORNERS)
-    error(EXIT_FAILURE, 0, "%s: most probably a bug! The number of corners "
-          "is more than %d. This is an internal value and cannot be set from "
-          "the outside. Most probably some bug has caused this un-normal "
-          "value. Please contact us at %s so we can solve this problem",
-          __func__, GAL_POLYGON_MAX_CORNERS, PACKAGE_BUGREPORT);
+    error(EXIT_FAILURE, 0, "%s: most probably a bug! The number of "
+          "corners is more than %d. This is an internal value and "
+          "cannot be set from the outside. Most probably some bug "
+          "has caused this un-normal value. Please contact us at %s "
+          "so we can solve this problem", __func__,
+          GAL_POLYGON_MAX_CORNERS, PACKAGE_BUGREPORT);
 
   /* For a check:
   printf("\n\nBefore sorting:\n");
@@ -210,7 +215,7 @@ gal_polygon_is_convex(double *v, size_t n)
         return 0;
     }
 
-  /* Check the edge between nth and 1st point */
+  /* Check the edge between nth and 1st point. */
   if(flag)
     {
       if( GAL_POLYGON_LEFT_OF_LINE(&v[(n-2)*2], &v[(n-1)*2], &v[0]) )
@@ -234,12 +239,11 @@ gal_polygon_is_convex(double *v, size_t n)
    vertices such that v[0] and v[1] are the positions of the first
    corner to be considered.
 
-   We will start from the edge connecting the last pixel to the first
-   pixel for the first step of the loop, for the rest, j is always
-   going to be one less than i.
- */
+   To optimize the process (avoid repetition): We start from the edge
+   connecting the last pixel to the first pixel for the first step of the
+   loop, for the rest, j is always going to be one less than i. */
 double
-gal_polygon_area(double *v, size_t n)
+gal_polygon_area_flat(double *v, size_t n)
 {
   double sum=0.0f;
   size_t i=0, j=n-1;
@@ -256,6 +260,47 @@ gal_polygon_area(double *v, size_t n)
 
 
 
+/* Spherical coordinates need special attention.*/
+double
+gal_polygon_area_sky(double *v, size_t n)
+{
+  int a1b0;
+  size_t i=0, j=n-1;
+  double *a, *b, sum=0.0f;
+
+  /* Go over all the vertices of the polygon. */
+  while(i<n)
+    {
+      /* For easy reading. */
+      a=v+j*2;
+      b=v+i*2;
+
+      /* We need to account for passing the two points pass over the line
+         of RA=0 (assuming that the vertices are not larger than 180
+         degrees apart!) */
+      if( fabs(a[0]-b[0]) < 180.0f)
+        sum+=GAL_POLYGON_CROSS_PRODUCT_SKY(a, b);
+      else
+        {
+          /* Add the smaller RA by 360. */
+          if(a[0]<b[0]) {a1b0=1; a[0]+=360.0f;}
+          else          {a1b0=0; b[0]+=360.0f;}
+
+          /* Add the cross product to the sum. */
+          sum+=GAL_POLYGON_CROSS_PRODUCT_SKY(a, b);
+
+          /* Return the changed value. */
+          if(a1b0) a[0]-=360.0f; else b[0]-=360.0f;
+        }
+      j=i++;
+    }
+  return fabs(sum)/2.0f;
+}
+
+
+
+
+
 /* This fuction test if a point is inside the polygon using winding number
   algorithm. See its wiki here:
   https://en.wikipedia.org/wiki/Point_in_polygon#Winding_number_algorithm
@@ -276,10 +321,10 @@ gal_polygon_is_inside(double *v, double *p, size_t n)
      crosses the polygon. */
   size_t wn=0, i=0, j=n-1;
 
-  /* Loop through all the edges of the polygon*/
+  /* Loop through all the edges of the polygon. */
   while(i<n)
     {
-      /* Edge from v[i] to v[i+1] in upward direction */
+      /* Edge from v[i] to v[i+1] in upward direction. */
       if(v[j*2+1] <= p[1])
         {
           if(v[i*2+1] > p[1])
@@ -288,14 +333,14 @@ gal_polygon_is_inside(double *v, double *p, size_t n)
               wn++;
         }
       else{
-        /* edge from v[i] to v[i+1] in downward direction */
+        /* Edge from v[i] to v[i+1] in downward direction. */
         if(v[i*2+1] <= p[1])
-          /* p right of edge is a downward intersection, decrease wn */
+          /* p right of edge is a downward intersection, decrease wn. */
           if( GAL_POLYGON_TRI_CROSS_PRODUCT(&v[j*2], &v[i*2], p) < 0 )
             wn--;
       }
 
-      /* Increment 'j' */
+      /* Increment 'j'. */
       j=i++;
 
       /* For a check:
@@ -319,7 +364,7 @@ gal_polygon_is_inside(double *v, double *p, size_t n)
    If the point is inside the polygon, it will always be to the left
    of the edge connecting the two vertices when the vertices are
    traversed in order. See the comments above 'gal_polygon_area' for an
-   explanation about i and j and the loop.*/
+   explanation about i and j and the loop. */
 int
 gal_polygon_is_inside_convex(double *v, double *p, size_t n)
 {
@@ -430,7 +475,7 @@ gal_polygon_to_counterclockwise(double *v, size_t n)
           j++;
         }
 
-      /* Put the vertices in the 'gal_data_t' object */
+      /* Put the vertices in the 'gal_data_t' object. */
       temp=gal_data_alloc(v, GAL_TYPE_FLOAT64, 1, &n, NULL, 0,
                           -1, 0, NULL, NULL, NULL);
 
@@ -472,7 +517,7 @@ seginfintersection(double *Aa, double *Ab, double *Ba, double *Bb,
   /* If all four points lie on the same line, there is infinite
      intersections, so return -1. If three of the points are
      collinear, then the point on the line segment that is collinear
-     with the infinite line is the intersection point.*/
+     with the infinite line is the intersection point. */
   if( Aacollinear && Abcollinear)
     return -1;
   else if( Aacollinear || Abcollinear)
@@ -705,7 +750,7 @@ polygon_leftof_vector(double *in, size_t n, double x, double y)
   polygon_rightmost_point(in, n, &r);
   test = (r.y-y)*(r.x-l.x) - (r.y-l.y)*(r.x-x);
 
-  /* Due to the choice of return value, we multiply 'test' by -1 */
+  /* Due to the choice of return value, we multiply 'test' by -1. */
   test = -1*test;
   return test?(test>0?1:-1):0;
 }
@@ -847,7 +892,7 @@ gal_polygon_vertices_sort(double *vertices, size_t n, size_t *ordinds)
   qsort(A, A_size, sizeof(struct point), polygon_compareA);
   qsort(B, B_size, sizeof(struct point), polygon_compareB);
 
-  /*Finally, we put the contents of A and B in a final sorted array.*/
+  /*Finally, we put the contents of A and B in a final sorted array. */
   for(i=0; i<A_size; i++) sorted[i]=A[i];
   for(j=0; j<B_size; j++) sorted[i++]=B[j];
 
@@ -857,7 +902,7 @@ gal_polygon_vertices_sort(double *vertices, size_t n, size_t *ordinds)
   */
 
   /* The temporary array is now used to find the location of points stored
-     in sorted array and assign index in ordinds accordingly.*/
+     in sorted array and assign index in ordinds accordingly. */
   for(i=0; i<n; i++)
     for(j=0; j<n; j++)
       if( tordinds[i].x == sorted[j].x && tordinds[i].y == sorted[j].y )
