@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -102,11 +102,13 @@ gal_table_displayflt_to_str(uint8_t fmt)
    of the output's elements. */
 gal_data_t *
 gal_table_info(char *filename, char *hdu, gal_list_str_t *lines,
-               size_t *numcols, size_t *numrows, int *tableformat)
+               size_t *numcols, size_t *numrows, int *tableformat,
+               char *hdu_option_name)
 {
   /* Get the table format and size (number of columns and rows). */
   if(filename && gal_fits_file_recognized(filename))
-    return gal_fits_tab_info(filename, hdu, numcols, numrows, tableformat);
+    return gal_fits_tab_info(filename, hdu, numcols, numrows, tableformat,
+                             hdu_option_name);
   else
     {
       *tableformat=GAL_TABLE_FORMAT_TXT;
@@ -230,7 +232,7 @@ gal_table_print_info(gal_data_t *allcols, size_t numcols, size_t numrows)
 /************************************************************************/
 
 /* Function to print regular expression error. This is taken from the GNU C
-   library manual, with small modifications to fit out style, */
+   library manual, with small modifications to fit out style. */
 static void
 table_regexerrorexit(int errcode, regex_t *compiled, char *input)
 {
@@ -252,7 +254,7 @@ table_regexerrorexit(int errcode, regex_t *compiled, char *input)
 
 
 
-/* Macro to set the string to search in */
+/* Macro to set the string to search in. */
 static char *
 table_set_strcheck(gal_data_t *col, int searchin)
 {
@@ -295,7 +297,7 @@ gal_table_list_of_indexs(gal_list_str_t *cols, gal_data_t *allcols,
   size_t i, nummatch, colcount=0, len;
   char *str, *strcheck, *tailptr, *errorstring;
 
-  /* Go over the given columns.  */
+  /* Go over the given columns. */
   if(cols)
     for(tmp=cols; tmp!=NULL; tmp=tmp->next)
       {
@@ -331,7 +333,7 @@ gal_table_list_of_indexs(gal_list_str_t *cols, gal_data_t *allcols,
 
                Here, we don't care about the details of a match, the only
                important thing is a match, so we are using the REG_NOSUB
-               flag.*/
+               flag. */
             regreturn=0;
             regreturn=regcomp(regex, str, ( ignorecase
                                             ? RE_SYNTAX_AWK | REG_ICASE
@@ -386,7 +388,7 @@ gal_table_list_of_indexs(gal_list_str_t *cols, gal_data_t *allcols,
 
                 /* Check if the given value is not larger than the number
                    of columns in the input catalog (note that the user is
-                   counting from 1, not 0!) */
+                   counting from 1, not 0!). */
                 if(tlong>numcols)
                   error(EXIT_FAILURE, 0, "%s: has %zu columns, but you "
                         "have asked for column number %ld",
@@ -395,7 +397,7 @@ gal_table_list_of_indexs(gal_list_str_t *cols, gal_data_t *allcols,
 
                 /* Everything seems to be fine, put this column number in
                    the output column numbers linked list. Note that
-                   internally, the column numbers start from 0, not 1.*/
+                   internally, the column numbers start from 0, not 1. */
                 gal_list_sizet_add(&indexll, tlong-1);
                 ++nummatch;
               }
@@ -483,7 +485,7 @@ gal_data_t *
 gal_table_read(char *filename, char *hdu, gal_list_str_t *lines,
                gal_list_str_t *cols, int searchin, int ignorecase,
                size_t numthreads, size_t minmapsize, int quietmmap,
-               size_t *colmatch)
+               size_t *colmatch, char *hdu_option_name)
 {
   int tableformat;
   gal_list_sizet_t *indexll;
@@ -492,7 +494,7 @@ gal_table_read(char *filename, char *hdu, gal_list_str_t *lines,
 
   /* First get the information of all the columns. */
   allcols=gal_table_info(filename, hdu, lines, &numcols, &numrows,
-                         &tableformat);
+                         &tableformat, hdu_option_name);
 
   /* If there was no actual data in the file, then return NULL. */
   if(allcols==NULL) return NULL;
@@ -503,7 +505,7 @@ gal_table_read(char *filename, char *hdu, gal_list_str_t *lines,
 
   /* Depending on the table format, read the columns into the output
      structure. Also note that after these functions, the 'indexll' will be
-     all freed (each popped element is actually freed).*/
+     all freed (each popped element is actually freed). */
   switch(tableformat)
     {
     case GAL_TABLE_FORMAT_TXT:
@@ -514,7 +516,8 @@ gal_table_read(char *filename, char *hdu, gal_list_str_t *lines,
     case GAL_TABLE_FORMAT_AFITS:
     case GAL_TABLE_FORMAT_BFITS:
       out=gal_fits_tab_read(filename, hdu, numrows, allcols, indexll,
-                            numthreads, minmapsize, quietmmap);
+                            numthreads, minmapsize, quietmmap,
+                            hdu_option_name);
       break;
 
     default:
@@ -579,7 +582,7 @@ gal_table_comments_add_intro(gal_list_str_t **comments,
 
   /* Program name: this will be the top of the list (first line). We will
      need to set the allocation flag for this one, because program_string
-     is usually statically allocated.*/
+     is usually statically allocated. */
   if(program_string)
     gal_list_str_add(comments, program_string, 1);
 }
@@ -592,9 +595,9 @@ gal_table_comments_add_intro(gal_list_str_t **comments,
    table will then be written into 'filename' with a format that is
    specified by 'tableformat'. */
 void
-gal_table_write(gal_data_t *cols, struct gal_fits_list_key_t **keylist,
+gal_table_write(gal_data_t *cols, struct gal_fits_list_key_t *keylist,
                 gal_list_str_t *comments, int tableformat, char *filename,
-                char *extname, uint8_t colinfoinstdout)
+                char *extname, uint8_t colinfoinstdout, int freekeys)
 {
   /* If a filename was given, then the tableformat is relevant and must be
      used. When the filename is empty, a text table must be printed on the
@@ -603,14 +606,15 @@ gal_table_write(gal_data_t *cols, struct gal_fits_list_key_t **keylist,
     {
       if(gal_fits_name_is_fits(filename))
         gal_fits_tab_write(cols, comments, tableformat, filename, extname,
-                           keylist);
+                           keylist, freekeys);
       else
         gal_txt_write(cols, keylist, comments, filename,
-                      colinfoinstdout, 0);
+                      colinfoinstdout, 0, freekeys);
     }
   else
     /* Write to standard output. */
-    gal_txt_write(cols, keylist, comments, filename, colinfoinstdout, 0);
+    gal_txt_write(cols, keylist, comments, filename, colinfoinstdout, 0,
+                  freekeys);
 }
 
 
@@ -624,12 +628,12 @@ gal_table_write_log(gal_data_t *logll, char *program_string,
 {
   char *msg;
 
-  /* Write all the comments into */
+  /* Write the program name and time first. */
   gal_table_comments_add_intro(&comments, program_string, rawtime);
 
-  /* Write the log file to disk */
+  /* Write the log file to disk. */
   gal_table_write(logll, NULL, comments, GAL_TABLE_FORMAT_TXT,
-                  filename, "LOG", 0);
+                  filename, "LOG", 0, 0);
 
   /* In verbose mode, print the information. */
   if(!quiet)
@@ -728,7 +732,7 @@ gal_table_cols_to_vector(gal_data_t *list)
   char *name, *unit=NULL, *inname=NULL;
   size_t i, j, dsize[2], num=gal_list_data_number(list);
 
-  /* If the list is empty or just has a single column, return itself.*/
+  /* If the list is empty or just has a single column, return itself. */
   if(num<2) return list;
 
   /* Go over the inputs na make sure they are all single dimensional and
