@@ -5,7 +5,8 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2018-2023 Free Software Foundation, Inc.
+     Fathma Mehnoor <fathmamehnoor@gmail.com>
+Copyright (C) 2018-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -37,6 +38,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/tiff.h>
 #include <gnuastro/pointer.h>
 
+#include <gnuastro-internal/checkset.h>
+
 
 
 
@@ -108,7 +111,7 @@ gal_tiff_suffix_is_tiff(char *name)
 
 /* Users may define the TIFF directory to read as a string, in that case,
    this function can be used to convert it to a 'size_t' for use in
-   'gal_tiff_read'.  */
+   'gal_tiff_read'. */
 size_t
 gal_tiff_dir_string_read(char *string)
 {
@@ -151,13 +154,13 @@ gal_tiff_dir_string_read(char *string)
 
 
 /*************************************************************
- **************        Read a JPEG image        **************
+ **************        Read a TIFF image        **************
  *************************************************************/
 #ifdef HAVE_LIBTIFF
 static void
 tiff_read_tag(TIFF *tif, ttag_t tag, void *out, char *filename, size_t dir)
 {
-  /* Read the tag */
+  /* Read the tag. */
   if( !TIFFGetField(tif, tag, out) )
     error(EXIT_FAILURE, 0, "%s: %s (dir %zu): tag %d couldn't be fetched",
           __func__, filename, dir, tag);
@@ -167,7 +170,7 @@ tiff_read_tag(TIFF *tif, ttag_t tag, void *out, char *filename, size_t dir)
 
 
 
-/* Convert the TIFF type code into Gnuastro's type code.*/
+/* Convert the TIFF type code into Gnuastro's type code. */
 static uint8_t
 tiff_type_read(TIFF *tif, char *filename, size_t dir)
 {
@@ -316,7 +319,7 @@ tiff_read_contig_strip_data(TIFF *tif, char *filename, size_t dir,
       /* Copy the contents of the buffer to the output array. Note that
          'ostart' is the byte count already, so the type is
          irrelevant. Thus, we can read 'out->array' as a 'char *'
-         pointer.*/
+         pointer. */
       memcpy( (char *)(out->array)+ostart, buf, nrow*scanline);
       ostart+=nrow*scanline;
     }
@@ -391,7 +394,7 @@ tiff_read_separate_strip_data(TIFF* tif, char *filename, size_t dir,
 /* The data have been read contiguously (the pixels for each color are
    beside each other). We need to separate the color channels into
    different datasets. We will also use this chance to reverse the order of
-   the rows */
+   the rows. */
 static gal_data_t *
 tiff_separate_channels_reverse(gal_data_t *out, size_t numch,
                                size_t minmapsize, int quietmmap)
@@ -563,7 +566,7 @@ tiff_img_read(TIFF *tif, char *filename, size_t dir, size_t minmapsize,
   /* When there are more than one channels and the colors are stored
      contiguously, we need to break up the array into multiple arrays. When
      any of these conditions don't hold, the channels are already
-     separated, we just need to reverse them.*/
+     separated, we just need to reverse them. */
   if( numch>1 && config==PLANARCONFIG_CONTIG )
     {
       sep=tiff_separate_channels_reverse(out, numch, minmapsize, quietmmap);
@@ -627,3 +630,153 @@ gal_tiff_read(char *filename, size_t dir, size_t minmapsize, int quietmmap)
   return NULL;
 #endif  /* HAVE_LIBTIFF */
 }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+/*************************************************************
+ ****************    Write into a TIFF file   ****************
+ *************************************************************/
+#ifdef HAVE_LIBTIFF
+static void
+tiff_img_write(TIFF *tif, gal_data_t *in, char *filename)
+{
+  gal_data_t *channel = in;
+  size_t index, offset, row, col, ch;
+  size_t numch = gal_list_data_number(in);
+  unsigned char *image, *buf, *colors[4] = {NULL};
+  size_t width = in->dsize[1], height = in->dsize[0];
+
+  /* Small sanity checks. */
+  if(numch==2 || numch>4)
+    error(EXIT_FAILURE, 0, "%s: only 1, 3, and 4 color channels are "
+          "acceptable, input is a list of %zu data sets", __func__,
+          numch);
+  if(in->type!=GAL_TYPE_UINT8)
+    error(EXIT_FAILURE, 0, "%s: input has a '%s' type, but TIFF "
+          "images can currently only have a 'uint8' type", __func__,
+          gal_type_name(in->type, 1));
+
+  /* Allocate memory for image. */
+  image = (unsigned char*)malloc(in->size * numch);
+  if(image == NULL)
+    error(EXIT_FAILURE, errno, "%s: %s: failed to allocate memory"
+          "for image", __func__, filename);
+
+  /* Extract color channels from input data. */
+  for(ch = 0; ch < numch; ch++)
+    {
+      if(channel != NULL && channel->array != NULL)
+        {
+          colors[ch] = channel->array;
+          channel = channel->next;
+        }
+      else
+        {
+          error(EXIT_FAILURE, errno, "%s: %s: missing or invalid color"
+                "channel", __func__, filename);
+          free(image);
+        }
+    }
+
+  /* Copy input data to image buffer. */
+  for(row = 0; row < height; row++)
+    {
+      for(col = 0; col < width; col++)
+        {
+          index = row * width + col;
+          offset = index * numch;
+
+          for(ch = 0; ch < numch; ch++)
+            image[offset + ch] = colors[ch][index];
+        }
+    }
+
+  /* Set TIFF tags. */
+  TIFFSetField(tif, TIFFTAG_IMAGEWIDTH, width);
+  TIFFSetField(tif, TIFFTAG_IMAGELENGTH, height);
+  if(numch==1)
+    TIFFSetField(tif, TIFFTAG_PHOTOMETRIC, PHOTOMETRIC_MINISBLACK);
+  else
+    TIFFSetField(tif, TIFFTAG_PHOTOMETRIC, PHOTOMETRIC_RGB);
+  TIFFSetField(tif, TIFFTAG_BITSPERSAMPLE, 8);
+  TIFFSetField(tif, TIFFTAG_SAMPLESPERPIXEL, numch);
+  TIFFSetField(tif, TIFFTAG_COMPRESSION, COMPRESSION_NONE);
+  TIFFSetField(tif, TIFFTAG_PLANARCONFIG, PLANARCONFIG_CONTIG);
+
+  /* Allocate memory for scanline buffer. */
+  errno=0;
+  buf = (unsigned char*)_TIFFmalloc(TIFFScanlineSize(tif));
+  if(buf == NULL)
+    error(EXIT_FAILURE, errno, "%s: %s: failed to allocate necessary"
+          "memory for the scanline buffer" , __func__, filename);
+
+  /* Write each scanline of the image to the TIFF file. */
+  for(row = height; row > 0; row--)
+    {
+      _TIFFmemcpy(buf, &image[(row - 1) * width * numch], width * numch);
+
+      if(TIFFWriteScanline(tif, buf, height - row, 0) < 0)
+        {
+          error(EXIT_FAILURE, errno, "%s: problem in writing to %s",
+                __func__, filename);
+          _TIFFfree(buf);
+          free(image);
+        }
+    }
+
+  /* Clean up. */
+  _TIFFfree(buf);
+  free(image);
+}
+#endif
+
+
+
+
+
+void
+gal_tiff_write(gal_data_t* in, char* filename)
+{
+/* The TIFF library exists and will be used. */
+#ifdef HAVE_LIBTIFF
+  TIFF* tif;
+
+  /* Make sure the input isn't NULL. */
+  if(in == NULL)
+    error(EXIT_FAILURE, 0, "%s: '%s', input data is NULL",
+          __func__, filename);
+
+  /* Open the TIFF file. */
+  tif = TIFFOpen(filename, "w");
+  if(tif == NULL)
+    error(EXIT_FAILURE, errno,
+          "%s: '%s' couldn't be opened for writing", __func__, filename);
+
+  /* Write to TIFF file. */
+  tiff_img_write(tif, in, filename);
+
+  /* Close file. */
+  TIFFClose(tif);
+
+  /* The TIFF library didn't exist. */
+#else
+  tiff_error_no_litiff(__func__);
+#endif
+}
